# Change Log

## [1.4.0](https://github.com/kivy/buildozer/tree/1.4.0) (2022-07-20)

[Full Changelog](https://github.com/kivy/buildozer/compare/1.3.0...1.4.0)

**Closed issues:**

- error [\#1461](https://github.com/kivy/buildozer/issues/1461)
- error [\#1460](https://github.com/kivy/buildozer/issues/1460)
- ModuleNotFoundError: No module named '\_bz2' [\#1457](https://github.com/kivy/buildozer/issues/1457)
- `java.nio.file.NoSuchFileException` [\#1456](https://github.com/kivy/buildozer/issues/1456)
- kivy app doesnt start on android [\#1455](https://github.com/kivy/buildozer/issues/1455)
- \(WSL\) buildozer adb doesn't recognize usb [\#1453](https://github.com/kivy/buildozer/issues/1453)
- Error: Command \[...\] returned non-zero exit status 1 [\#1452](https://github.com/kivy/buildozer/issues/1452)
- Command failed: /home/username/.buildozer/android/platform/android-sdk/tools/bin/sdkmanager --sdk\_root=/home/username/.buildozer/android/platform/android-sdk platform-tools [\#1449](https://github.com/kivy/buildozer/issues/1449)
- gradlew assembly Debug execution error when building apk [\#1447](https://github.com/kivy/buildozer/issues/1447)
- How to run Python script in background in android? [\#1446](https://github.com/kivy/buildozer/issues/1446)
- buildozer appclean doesnt work. [\#1443](https://github.com/kivy/buildozer/issues/1443)
- Flags android.gradle\_dependencies && android.add\_jars don't work. [\#1442](https://github.com/kivy/buildozer/issues/1442)
- ModuleNotFoundError: No module named 'PIL' [\#1440](https://github.com/kivy/buildozer/issues/1440)
- Bulldozer error while running "buildozer -v android debug" [\#1439](https://github.com/kivy/buildozer/issues/1439)
- started app on three different andoid phones - there is no internet connection on 2 of them [\#1434](https://github.com/kivy/buildozer/issues/1434)
- Not Able to change the python version under buildozer 1.3.0 [\#1432](https://github.com/kivy/buildozer/issues/1432)
- ndk r22 invalid  [\#1431](https://github.com/kivy/buildozer/issues/1431)
- error building numpy with bulldozer [\#1426](https://github.com/kivy/buildozer/issues/1426)
- sh.CommandNotFound: cmake [\#1424](https://github.com/kivy/buildozer/issues/1424)
- Compile-time name 'JNIUS\_PYTHON3' not defined [\#1422](https://github.com/kivy/buildozer/issues/1422)
- Error Building hostpython3 for arm64-v8a with buildozer [\#1421](https://github.com/kivy/buildozer/issues/1421)
- building for android failed [\#1420](https://github.com/kivy/buildozer/issues/1420)
- Error "Aidl not found, please install it." [\#1416](https://github.com/kivy/buildozer/issues/1416)
- Buildozer Release Signign Issue [\#1415](https://github.com/kivy/buildozer/issues/1415)
- Unable to run the buildozer command on initial application [\#1414](https://github.com/kivy/buildozer/issues/1414)
- buildozer -v android debug error,please help me,thank you! [\#1413](https://github.com/kivy/buildozer/issues/1413)
- Buildozer failed to create android app [\#1412](https://github.com/kivy/buildozer/issues/1412)
- module encodings found error or something else [\#1408](https://github.com/kivy/buildozer/issues/1408)
- \[ERROR\]:   Build failed: Requested API target 27 is not available, install it with the SDK android tool. [\#1404](https://github.com/kivy/buildozer/issues/1404)
- buildozer requirements for firebase-admin Python?  [\#1402](https://github.com/kivy/buildozer/issues/1402)
- I am given the following error, which I believe is due to recent changes for aab support in buildozer:  " This buildozer version requires a python-for-android version with AAB \(Android App Bundle\) support. Please update your pinned version accordingly [\#1401](https://github.com/kivy/buildozer/issues/1401)
- How to mention Python modules used in Kivy buildozer.spec file? [\#1400](https://github.com/kivy/buildozer/issues/1400)
- Приложение вылетает при запуске [\#1399](https://github.com/kivy/buildozer/issues/1399)
- Buildozer deploy failed with python3 -m venv venv command [\#1389](https://github.com/kivy/buildozer/issues/1389)
- Gradlew Build error for Android on Linux [\#1371](https://github.com/kivy/buildozer/issues/1371)
- AAB [\#1353](https://github.com/kivy/buildozer/issues/1353)
- Error creating apk on Macos Big Sur [\#1345](https://github.com/kivy/buildozer/issues/1345)
- BUILD FAILED [\#1335](https://github.com/kivy/buildozer/issues/1335)

**Merged pull requests:**

- Updates default buildozer.spec NDK from 19b to 23b [\#1462](https://github.com/kivy/buildozer/pull/1462) ([misl6](https://github.com/misl6))
- use p4a --add-source instead of manual copy of java files [\#1450](https://github.com/kivy/buildozer/pull/1450) ([tito](https://github.com/tito))
- fix aar build [\#1444](https://github.com/kivy/buildozer/pull/1444) ([mzakharo](https://github.com/mzakharo))
- Our self-hosted Apple Silicon runner now has been migrated to actions/runner v2.292.0 which now supports arm64 natively [\#1438](https://github.com/kivy/buildozer/pull/1438) ([misl6](https://github.com/misl6))
- Changes for NDK23 [\#1427](https://github.com/kivy/buildozer/pull/1427) ([HyTurtle](https://github.com/HyTurtle))
- Bump version to 1.4.0.dev0 [\#1411](https://github.com/kivy/buildozer/pull/1411) ([misl6](https://github.com/misl6))

## [1.3.0](https://github.com/kivy/buildozer/tree/1.3.0) (2022-03-13)
[Full Changelog](https://github.com/kivy/buildozer/compare/1.2.0...1.3.0)

**Merged pull requests:**

- Improves iOS CI workflow and adds Apple Silicon M1 runner [\#1393](https://github.com/kivy/buildozer/pull/1393) ([misl6](https://github.com/misl6))
- iOS: force archive iOS destination [\#1392](https://github.com/kivy/buildozer/pull/1392) ([syrykh](https://github.com/syrykh))
- simple typo [\#1390](https://github.com/kivy/buildozer/pull/1390) ([Jessime](https://github.com/Jessime))
- Bump support-request to v2. Previous integration has been shut down. [\#1385](https://github.com/kivy/buildozer/pull/1385) ([misl6](https://github.com/misl6))
- Add android.add\_assets [\#1382](https://github.com/kivy/buildozer/pull/1382) ([RobertFlatt](https://github.com/RobertFlatt))
- add the option p4a.extra\_args [\#1369](https://github.com/kivy/buildozer/pull/1369) ([antocuni](https://github.com/antocuni))
- Fix CI tests for iOS and Android [\#1365](https://github.com/kivy/buildozer/pull/1365) ([misl6](https://github.com/misl6))
- Add aab \(Android App Bundle\) support [\#1356](https://github.com/kivy/buildozer/pull/1356) ([misl6](https://github.com/misl6))
- Fixes deprecated plistlib API [\#1347](https://github.com/kivy/buildozer/pull/1347) ([meow464](https://github.com/meow464))
- docs: fix a few simple typos [\#1327](https://github.com/kivy/buildozer/pull/1327) ([tshirtman](https://github.com/tshirtman))
- use HTTPS urls [\#1319](https://github.com/kivy/buildozer/pull/1319) ([obfusk](https://github.com/obfusk))
- iOS OTA manifest generation for in-house app distribution [\#1317](https://github.com/kivy/buildozer/pull/1317) ([syrykh](https://github.com/syrykh))
- android: adaptive icon/launcher: expose p4a options in buildozer.spec [\#1312](https://github.com/kivy/buildozer/pull/1312) ([SomberNight](https://github.com/SomberNight))
- Add enable\_androidx [\#1311](https://github.com/kivy/buildozer/pull/1311) ([RobertFlatt](https://github.com/RobertFlatt))
- Update iOS codesign options [\#1307](https://github.com/kivy/buildozer/pull/1307) ([syrykh](https://github.com/syrykh))
- Allow setting custom p4a URL instead of fork [\#1305](https://github.com/kivy/buildozer/pull/1305) ([syrykh](https://github.com/syrykh))
- chore : Fixed code quality issues [\#1300](https://github.com/kivy/buildozer/pull/1300) ([powerexploit](https://github.com/powerexploit))
- added few additional options for android p4a builds [\#1275](https://github.com/kivy/buildozer/pull/1275) ([vesellov](https://github.com/vesellov))
- :recycle: Minor check\_requirements\(\) refactoring [\#1274](https://github.com/kivy/buildozer/pull/1274) ([AndreMiras](https://github.com/AndreMiras))
- Allow displaying only the logcat of our app. [\#1272](https://github.com/kivy/buildozer/pull/1272) ([tshirtman](https://github.com/tshirtman))
- fix ndk version check & download link [\#1271](https://github.com/kivy/buildozer/pull/1271) ([obfusk](https://github.com/obfusk))
- Let buildozer.spec files pin to a specific p4a commit hash [\#1269](https://github.com/kivy/buildozer/pull/1269) ([xloem](https://github.com/xloem))
- Change android.manifest\_placeholders default to None [\#1265](https://github.com/kivy/buildozer/pull/1265) ([misl6](https://github.com/misl6))
- Pass debug loglevel down through to python for android [\#1260](https://github.com/kivy/buildozer/pull/1260) ([xloem](https://github.com/xloem))
- Use develop branch for automated tests [\#1257](https://github.com/kivy/buildozer/pull/1257) ([misl6](https://github.com/misl6))
- Add android.adb\_args option [\#1238](https://github.com/kivy/buildozer/pull/1238) ([germn](https://github.com/germn))
- Add support for p4a --feature option [\#1229](https://github.com/kivy/buildozer/pull/1229) ([rambo](https://github.com/rambo))
- Add option for controlling p4a distutils support, fixes \#1224 [\#1225](https://github.com/kivy/buildozer/pull/1225) ([rambo](https://github.com/rambo))
- WSL workaround now accommodates WSL 2 [\#1220](https://github.com/kivy/buildozer/pull/1220) ([stefan-sherwood](https://github.com/stefan-sherwood))
- Add android.backup\_rules parameter to buildozer.spec [\#1219](https://github.com/kivy/buildozer/pull/1219) ([Jorilx](https://github.com/Jorilx))
- make include\_exts etc. properly case-insentitive [\#1217](https://github.com/kivy/buildozer/pull/1217) ([obfusk](https://github.com/obfusk))
- Add manifestPlaceholders feature [\#1212](https://github.com/kivy/buildozer/pull/1212) ([misl6](https://github.com/misl6))
- Add support for --presplash-lottie option of p4a [\#1208](https://github.com/kivy/buildozer/pull/1208) ([tshirtman](https://github.com/tshirtman))
- Fix issue \#881: Add android.allow\_backup parameter to buildozer.spec [\#1206](https://github.com/kivy/buildozer/pull/1206) ([Jorilx](https://github.com/Jorilx))
- Add link to GitHub action [\#1198](https://github.com/kivy/buildozer/pull/1198) ([ArtemSBulgakov](https://github.com/ArtemSBulgakov))
- Fixes heading for iOS target [\#1175](https://github.com/kivy/buildozer/pull/1175) ([fullbuffer](https://github.com/fullbuffer))
- :white\_check\_mark: Increases ios target test coverage [\#1171](https://github.com/kivy/buildozer/pull/1171) ([AndreMiras](https://github.com/AndreMiras))
- :white\_check\_mark: Unit test ios target [\#1168](https://github.com/kivy/buildozer/pull/1168) ([AndreMiras](https://github.com/AndreMiras))
- Expand "~" before every path normalization. [\#1165](https://github.com/kivy/buildozer/pull/1165) ([pakal](https://github.com/pakal))
- :green\_apple: Improves iOS support [\#1160](https://github.com/kivy/buildozer/pull/1160) ([AndreMiras](https://github.com/AndreMiras))
- :construction\_worker: Moves Android build to dedicated workflow file [\#1158](https://github.com/kivy/buildozer/pull/1158) ([AndreMiras](https://github.com/AndreMiras))
- SafeConfigParser deprecated. [\#1155](https://github.com/kivy/buildozer/pull/1155) ([Julian-O](https://github.com/Julian-O))
- Declare Buildozer to be Stable [\#1147](https://github.com/kivy/buildozer/pull/1147) ([Julian-O](https://github.com/Julian-O))
- :fire: Drops garden support [\#1142](https://github.com/kivy/buildozer/pull/1142) ([AndreMiras](https://github.com/AndreMiras))
- :arrow\_up: Bumps Ubuntu and OpenJDK versions [\#1140](https://github.com/kivy/buildozer/pull/1140) ([AndreMiras](https://github.com/AndreMiras))
- Post release bump 1.2.0.dev0 [\#1139](https://github.com/kivy/buildozer/pull/1139) ([AndreMiras](https://github.com/AndreMiras))
- Update quickstart.rst for Windows 10 [\#1124](https://github.com/kivy/buildozer/pull/1124) ([arqeco](https://github.com/arqeco))
- Update instalation.rst for Windows 10 [\#1123](https://github.com/kivy/buildozer/pull/1123) ([arqeco](https://github.com/arqeco))

## [1.2.0](https://github.com/kivy/buildozer/tree/1.2.0) (2020-05-30)
[Full Changelog](https://github.com/kivy/buildozer/compare/1.1.0...1.2.0)

**Merged pull requests:**

- Bumps to latest Cython version [\#1132](https://github.com/kivy/buildozer/pull/1132) ([AndreMiras](https://github.com/AndreMiras))
- Also integration test on macOS [\#1131](https://github.com/kivy/buildozer/pull/1131) ([AndreMiras](https://github.com/AndreMiras))
- Tests android.numeric\_version config [\#1129](https://github.com/kivy/buildozer/pull/1129) ([AndreMiras](https://github.com/AndreMiras))
- Refactored the TargetAndroid tests [\#1127](https://github.com/kivy/buildozer/pull/1127) ([pavelsof](https://github.com/pavelsof))
- Adds p4a --numeric-version support [\#1126](https://github.com/kivy/buildozer/pull/1126) ([AndreMiras](https://github.com/AndreMiras))
- Linter fixes and README.md update [\#1118](https://github.com/kivy/buildozer/pull/1118) ([AndreMiras](https://github.com/AndreMiras))
- Removes Python 2 constructions [\#1114](https://github.com/kivy/buildozer/pull/1114) ([AndreMiras](https://github.com/AndreMiras))

## [1.1.0](https://github.com/kivy/buildozer/tree/1.1.0) (2020-05-18)
[Full Changelog](https://github.com/kivy/buildozer/compare/1.0...1.1.0)

**Fixed bugs:**

- [Docker image] SSLError("Can't connect to HTTPS URL because the SSL module is not available.") [\#1096](https://github.com/kivy/buildozer/issues/1096)
- NameError: name 'raw\_input' is not defined [\#1070](https://github.com/kivy/buildozer/issues/1070)
- Setup coverage testing [\#1058](https://github.com/kivy/buildozer/issues/1058)
- AttributeError: 'function' object has no attribute 'glob' [\#1044](https://github.com/kivy/buildozer/issues/1044)

**Closed issues:**

- Pygallary [\#1109](https://github.com/kivy/buildozer/issues/1109)
- Buildozer compilation ERROR: No matching distribution found for hostpython2 (from -r requirements.txt (line 2)) [\#1104](https://github.com/kivy/buildozer/issues/1104)
- Circular errors with Java version and Android SDK [\#1103](https://github.com/kivy/buildozer/issues/1103)
- APK not running on Android 10? [\#1102](https://github.com/kivy/buildozer/issues/1102)
- Buildozer command fails: Could not fetch URL https://pypi.org/simple/pip/: There was a problem confirming the ssl certificate [\#1095](https://github.com/kivy/buildozer/issues/1095)
- Command Failed Error [\#1092](https://github.com/kivy/buildozer/issues/1092)
- APK Can't be install (package can't be install in android) [\#1091](https://github.com/kivy/buildozer/issues/1091)
- buildozer Install python 3.8.1 [\#1090](https://github.com/kivy/buildozer/issues/1090)
- i have weak reference error while using python 3.8 [\#1089](https://github.com/kivy/buildozer/issues/1089)
- buildozer is choosing odd venv, and using a different python? [\#1080](https://github.com/kivy/buildozer/issues/1080)
- Fatal Python error: init\_fs\_encoding: failed to get the Python codec of the filesystem encoding [\#1076](https://github.com/kivy/buildozer/issues/1076)
- Buildozer just wont compile my app [\#1074](https://github.com/kivy/buildozer/issues/1074)
- Autoreconf not found? [\#1072](https://github.com/kivy/buildozer/issues/1072)
- error while buildozer android debug deploy run [\#1064](https://github.com/kivy/buildozer/issues/1064)
- Syntax error in Kivy and KivyMD dependencies file when using Buildozer to compile KivyMD app [\#1051](https://github.com/kivy/buildozer/issues/1051)
- Adding CFFI as a Buildozer requirement breaks the Android build [\#1050](https://github.com/kivy/buildozer/issues/1050)
- Is buildozer compatible with Python 3.7 [\#1048](https://github.com/kivy/buildozer/issues/1048)
- Could not resolve org.jetbrains.kotlin:kotlin-stdlib-jre8:1.2.0 [\#1042](https://github.com/kivy/buildozer/issues/1042)
- Error while running buildozer android debug deploy [\#1038](https://github.com/kivy/buildozer/issues/1038)
- cant able to build apk on linux with python3 [\#1033](https://github.com/kivy/buildozer/issues/1033)
- Keystore was tampered with, or password was incorrect [\#1028](https://github.com/kivy/buildozer/issues/1028)
- Windows support to build Android APK [\#1022](https://github.com/kivy/buildozer/issues/1022)
- How to make third party site-packages 'requests' run on Android [\#1021](https://github.com/kivy/buildozer/issues/1021)
- Crash on buildozer android debug command. Command failed: /usr/bin/python -m pythonforandroid.toolchain [\#1017](https://github.com/kivy/buildozer/issues/1017)
- Build failed: Couldn't find executable for CC [\#1014](https://github.com/kivy/buildozer/issues/1014)
- Cloning Error of python-for-android [\#1008](https://github.com/kivy/buildozer/issues/1008)
- checking whether the C compiler works... no [\#1007](https://github.com/kivy/buildozer/issues/1007)
- Kivy :How to ask for storage permission when app starts [\#1004](https://github.com/kivy/buildozer/issues/1004)
- Buildozer :No module named 'numpy.core.\_multiarray\_umath' [\#1002](https://github.com/kivy/buildozer/issues/1002)
- Kivy app Crashes while import openpyxl [\#1001](https://github.com/kivy/buildozer/issues/1001)
- Warning when i run "buildozer -v android debug" [\#982](https://github.com/kivy/buildozer/issues/982)
- sdkmanager is notinstalled [\#927](https://github.com/kivy/buildozer/issues/927)

**Merged pull requests:**

- Update README.md [\#1111](https://github.com/kivy/buildozer/pull/1111) ([tshirtman](https://github.com/tshirtman))
- Fixes Docker apt cache missed [\#1107](https://github.com/kivy/buildozer/pull/1107) ([AndreMiras](https://github.com/AndreMiras))
- Adds libssl-dev to the install dependencies [\#1106](https://github.com/kivy/buildozer/pull/1106) ([AndreMiras](https://github.com/AndreMiras))
- Automatically publish to PyPI upon tagging [\#1105](https://github.com/kivy/buildozer/pull/1105) ([AndreMiras](https://github.com/AndreMiras))
- Fix punctuation and typo in README.md [\#1101](https://github.com/kivy/buildozer/pull/1101) ([hematogender](https://github.com/hematogender))
- Build integration test [\#1100](https://github.com/kivy/buildozer/pull/1100) ([AndreMiras](https://github.com/AndreMiras))
- Fixes missing libssl-dev dependency [\#1099](https://github.com/kivy/buildozer/pull/1099) ([AndreMiras](https://github.com/AndreMiras))
- Drops Python 2 support [\#1094](https://github.com/kivy/buildozer/pull/1094) ([AndreMiras](https://github.com/AndreMiras))
- Checks SDK, NDK and p4a get downloaded on first run [\#1093](https://github.com/kivy/buildozer/pull/1093) ([AndreMiras](https://github.com/AndreMiras))
- Integration testing [\#1083](https://github.com/kivy/buildozer/pull/1083) ([AndreMiras](https://github.com/AndreMiras))
- Also tests against macOS platform [\#1078](https://github.com/kivy/buildozer/pull/1078) ([AndreMiras](https://github.com/AndreMiras))
- Fix NameError with Python 3 and iOS target [\#1071](https://github.com/kivy/buildozer/pull/1071) ([lerela](https://github.com/lerela))
- Unit tests TargetAndroid.build\_package() [\#1069](https://github.com/kivy/buildozer/pull/1069) ([AndreMiras](https://github.com/AndreMiras))
- Dedicated Docker build/run job [\#1068](https://github.com/kivy/buildozer/pull/1068) ([AndreMiras](https://github.com/AndreMiras))
- F841: local variable is assigned to but never used [\#1066](https://github.com/kivy/buildozer/pull/1066) ([AndreMiras](https://github.com/AndreMiras))
- PEP8 organisation and fixes [\#1065](https://github.com/kivy/buildozer/pull/1065) ([AndreMiras](https://github.com/AndreMiras))
- Fixes coveralls.io on pull requests [\#1063](https://github.com/kivy/buildozer/pull/1063) ([AndreMiras](https://github.com/AndreMiras))
- Coveralls TOKEN is only available on branch master [\#1062](https://github.com/kivy/buildozer/pull/1062) ([AndreMiras](https://github.com/AndreMiras))
- Starts unit testing buildozer/targets/android.py [\#1061](https://github.com/kivy/buildozer/pull/1061) ([AndreMiras](https://github.com/AndreMiras))
- Setup coverage testing [\#1060](https://github.com/kivy/buildozer/pull/1060) ([AndreMiras](https://github.com/AndreMiras))
- Fix Dockerfile dependencies [\#1053](https://github.com/kivy/buildozer/pull/1053) ([Sirfanas](https://github.com/Sirfanas))
- Updates default buildozer.spec NDK from 17c to 19b [\#1041](https://github.com/kivy/buildozer/pull/1041) ([AndreMiras](https://github.com/AndreMiras))
- Fix config typo in default.spec [\#1026](https://github.com/kivy/buildozer/pull/1026) ([touilleMan](https://github.com/touilleMan))
- Android gradle build: fix apk name [\#1025](https://github.com/kivy/buildozer/pull/1025) ([SomberNight](https://github.com/SomberNight))

## [1.0](https://github.com/kivy/buildozer/tree/1.0) (2019-12-22)
[Full Changelog](https://github.com/kivy/buildozer/compare/0.39...1.0)

**Fixed bugs:**

- Accept license terms prompt is not visible [\#916](https://github.com/kivy/buildozer/issues/916)
- Unable to build release.  File "/usr/lib/python3.6/shutil.py", line 96, in copyfile with open\(src, 'rb'\) as fsrc: IOError: \[Errno 2\] No such file or directory:  [\#851](https://github.com/kivy/buildozer/issues/851)
- error: cannot find -lpython3.7 [\#842](https://github.com/kivy/buildozer/issues/842)
- android.accept\_sdk\_license may misbehave [\#816](https://github.com/kivy/buildozer/issues/816)
- Python3 error with pexpect [\#221](https://github.com/kivy/buildozer/issues/221)

**Closed issues:**

- Sup Req : Buildozer debug does not complete - Error threading.py, sh.py, etc.. [\#1000](https://github.com/kivy/buildozer/issues/1000)
- Buildozer failed to execute the last command [\#999](https://github.com/kivy/buildozer/issues/999)
- Android fullscreen mode: cannot hide status bar! [\#989](https://github.com/kivy/buildozer/issues/989)
- buildozer uses wrong python version and disrespects requirement versions [\#988](https://github.com/kivy/buildozer/issues/988)
- The version of Kivy installed on this system is too old. [\#987](https://github.com/kivy/buildozer/issues/987)
- Failed to download any source lists!  [\#986](https://github.com/kivy/buildozer/issues/986)
- Aidl cannot be executed error buildozer [\#984](https://github.com/kivy/buildozer/issues/984)
- buildozer debug error "\[WARNING\]" when i run buildozer andriod debug  [\#980](https://github.com/kivy/buildozer/issues/980)
- Building kivy app with python3 requirement gives "No compiled python is present to zip, skipping." warning and "Unable to import kivy.\_clock. Have you perhaps forgotten to compile kivy? ..." error when run on android device. [\#977](https://github.com/kivy/buildozer/issues/977)
- Java And Python-for-android toolchain errors [\#975](https://github.com/kivy/buildozer/issues/975)
- buildozer + python3 [\#973](https://github.com/kivy/buildozer/issues/973)
- Error while running ".buildozer.../native-build/python -OO -m compileall -b -f /.../app [\#972](https://github.com/kivy/buildozer/issues/972)
- buildozer fails with kivymd link [\#968](https://github.com/kivy/buildozer/issues/968)
- ndk\_platform doesn't exist: /home/rr/android-ndk-r20/platforms/android-20/arch-arm [\#966](https://github.com/kivy/buildozer/issues/966)
- Paused at  Installing/updating SDK platform tools if necessary [\#965](https://github.com/kivy/buildozer/issues/965)
- java.lang.NoClassDefFoundError: javax/xml/bind/annotation/XmlSchema [\#962](https://github.com/kivy/buildozer/issues/962)
- please add aidl into Dockerfile [\#960](https://github.com/kivy/buildozer/issues/960)
- Missing \_ctypes module [\#955](https://github.com/kivy/buildozer/issues/955)
- Kivy-Buildozer release version doesnt upload google store [\#953](https://github.com/kivy/buildozer/issues/953)
- buildozer using wrong kivy version [\#943](https://github.com/kivy/buildozer/issues/943)
- buildozer ndk-api=21 error [\#942](https://github.com/kivy/buildozer/issues/942)
- app crash [\#939](https://github.com/kivy/buildozer/issues/939)
- ERROR: JAVA\_HOME is set to an invalid directory: /usr/lib/jvm/java-8-oracle [\#929](https://github.com/kivy/buildozer/issues/929)
- no-issue [\#926](https://github.com/kivy/buildozer/issues/926)
- can't find file to patch toggle\_jpg\_png\_webp.patch [\#921](https://github.com/kivy/buildozer/issues/921)
- No matching distribution found for io [\#915](https://github.com/kivy/buildozer/issues/915)
- Error: No matching distribution found for io\(from -r requirements.txt \(line 5\)\) [\#914](https://github.com/kivy/buildozer/issues/914)
- I'm also experiencing the same issue, using macOS 10.14.3 and no Docker -- just plain Buildozer from the PyPi repo. What is the recommended course of action to fix this? [\#913](https://github.com/kivy/buildozer/issues/913)
- app crash [\#911](https://github.com/kivy/buildozer/issues/911)
- warnings while building apk using buildozer [\#910](https://github.com/kivy/buildozer/issues/910)
- buildozer error please help me!! [\#906](https://github.com/kivy/buildozer/issues/906)
- My application does not open in android but if it works in geany, help please. [\#903](https://github.com/kivy/buildozer/issues/903)
- \[Docker image\] Can't compile apk: /bin/tar ... "Cannot utime: Operation not permitted"  [\#902](https://github.com/kivy/buildozer/issues/902)
- Fails to call numpy fft on android [\#899](https://github.com/kivy/buildozer/issues/899)
- Command failed: /usr/bin/python3 -m pythonforandroid.toolchain [\#898](https://github.com/kivy/buildozer/issues/898)
-  error: C compiler cannot create executables [\#897](https://github.com/kivy/buildozer/issues/897)
- stopped at "Installing/updating SDK platform tools if necessary" [\#896](https://github.com/kivy/buildozer/issues/896)
- ValueError: Tried to access ndk\_ver but it has not been set - this should not happen, something went wrong! [\#893](https://github.com/kivy/buildozer/issues/893)
- Buildozer not installing from custom source folders [\#892](https://github.com/kivy/buildozer/issues/892)
- Error with build requirements PIL \(Python 3\) [\#890](https://github.com/kivy/buildozer/issues/890)
- rocker plants.cvs -an active -r -p rco.png  [\#889](https://github.com/kivy/buildozer/issues/889)
- rocker plants.cvs -an active -r -p rco.png  [\#888](https://github.com/kivy/buildozer/issues/888)
- rocker plants.cvs -an active -r -p rco.png  [\#887](https://github.com/kivy/buildozer/issues/887)
- rocker plants.cvs -an active -r -p rco.png  [\#886](https://github.com/kivy/buildozer/issues/886)
- rocker plants.cvs -an active -r -p rco.png  [\#885](https://github.com/kivy/buildozer/issues/885)
- host=arm-linux-androideabi [\#884](https://github.com/kivy/buildozer/issues/884)
- Buildozer has attribute errors and will not run [\#883](https://github.com/kivy/buildozer/issues/883)
- buildozer on osx not working [\#879](https://github.com/kivy/buildozer/issues/879)
- Android API Issue [\#877](https://github.com/kivy/buildozer/issues/877)
- What is the way to add folders and files? [\#875](https://github.com/kivy/buildozer/issues/875)
- Buildozer Error  [\#874](https://github.com/kivy/buildozer/issues/874)
- Problem with "Unpacking sdl2\_image" and "Parent module 'pythonforandroid.recipes' not found" [\#872](https://github.com/kivy/buildozer/issues/872)
- buildozer android debug deploy is stuck [\#870](https://github.com/kivy/buildozer/issues/870)
- running autoreconf -vif [\#866](https://github.com/kivy/buildozer/issues/866)
- Exception in thread "main" java.lang.NoClassDefFoundError: javax/xml/bind/annotation/XmlSchema [\#862](https://github.com/kivy/buildozer/issues/862)
- Can not build x86 APK file [\#861](https://github.com/kivy/buildozer/issues/861)
- But then a lot more issues, deep in the weeds now. [\#858](https://github.com/kivy/buildozer/issues/858)
- Create tests for PR fix bug when logcat value which cannot be decode to utf-8 [\#857](https://github.com/kivy/buildozer/issues/857)
- Can't Cythonize pyjnius: TypeError: can't pickle Argument objects [\#850](https://github.com/kivy/buildozer/issues/850)
- buildozer -h complains about NoneType target [\#849](https://github.com/kivy/buildozer/issues/849)
- Building failes at compiling openssl\[armeabi-v7a\] [\#841](https://github.com/kivy/buildozer/issues/841)
- Applying patches for libffi\[armeabi-v7a\] [\#840](https://github.com/kivy/buildozer/issues/840)
- Errors while running buildozer android debug deploy [\#832](https://github.com/kivy/buildozer/issues/832)
- "Command failed" when running "buildozer android debug deploy run" [\#829](https://github.com/kivy/buildozer/issues/829)
- Build Python3 for Android with Azure-keyvault and merest [\#828](https://github.com/kivy/buildozer/issues/828)
- Outdated Android NDK download URL in Kivy Virtual Machine [\#827](https://github.com/kivy/buildozer/issues/827)
- App crashes on startup [\#826](https://github.com/kivy/buildozer/issues/826)
- I found the origin of the problem mentioned in issue \#694 \(Aidl not found\) [\#824](https://github.com/kivy/buildozer/issues/824)
- download\(\) is not CI log friendly [\#823](https://github.com/kivy/buildozer/issues/823)
- Application stuck in portrait mode [\#820](https://github.com/kivy/buildozer/issues/820)
- Orientation landscape when set to portrait [\#818](https://github.com/kivy/buildozer/issues/818)
- Certain python requirements fail due to `\_ctypes` [\#815](https://github.com/kivy/buildozer/issues/815)
- Running buildozer help crashes [\#813](https://github.com/kivy/buildozer/issues/813)
- \[Buildozer 0.40.dev0, Buildozer 0.39\] AttributeError: 'Buildozer' object has no attribute 'translate\_target' [\#812](https://github.com/kivy/buildozer/issues/812)
- Version number failing to be added to apk [\#810](https://github.com/kivy/buildozer/issues/810)
- Virtual machine out of date [\#764](https://github.com/kivy/buildozer/issues/764)
- Docker doesn't build [\#751](https://github.com/kivy/buildozer/issues/751)
- Buildozer exit code on recipe fail [\#674](https://github.com/kivy/buildozer/issues/674)
- not able to release apk in release mode - build failed [\#363](https://github.com/kivy/buildozer/issues/363)
- Issue with NDK r11b [\#308](https://github.com/kivy/buildozer/issues/308)
- Feature: Create a compat.py for correct PY3 support and implement it [\#300](https://github.com/kivy/buildozer/issues/300)
- Curl missing in KivyVM [\#296](https://github.com/kivy/buildozer/issues/296)
- Virtual machine image could have better support for international keyboards [\#295](https://github.com/kivy/buildozer/issues/295)
- Virtual machine image does not have enough disk space [\#294](https://github.com/kivy/buildozer/issues/294)
- Not quite an issue, just some dependency stuff [\#247](https://github.com/kivy/buildozer/issues/247)
- \# Command failed: ./distribute.sh -m "kivy" -d "stapp" [\#204](https://github.com/kivy/buildozer/issues/204)
- Command ./distribute.sh failed -- no buildozer.spec found when it exists [\#203](https://github.com/kivy/buildozer/issues/203)
- buildozer -v android debug : Compile fails at fcntlmodule.c [\#196](https://github.com/kivy/buildozer/issues/196)
- Build errors on OSX 10.10 \(for android\) [\#165](https://github.com/kivy/buildozer/issues/165)
- Feature Request: Vagrantfile [\#154](https://github.com/kivy/buildozer/issues/154)

**Merged pull requests:**

- Feature GitHub actions [\#1005](https://github.com/kivy/buildozer/pull/1005) ([tito](https://github.com/tito))
- Fixes test\_p4a\_recommended\_android\_ndk\_found\(\) mocking [\#983](https://github.com/kivy/buildozer/pull/983) ([AndreMiras](https://github.com/AndreMiras))
- Fixes packaging for current p4a develop branch [\#978](https://github.com/kivy/buildozer/pull/978) ([misl6](https://github.com/misl6))
- Updates install instructions and troubleshooting [\#976](https://github.com/kivy/buildozer/pull/976) ([AndreMiras](https://github.com/AndreMiras))
- fix: show output of sdk update if auto\_accept\_license is false [\#970](https://github.com/kivy/buildozer/pull/970) ([tshirtman](https://github.com/tshirtman))
- Add libs only for current arch [\#969](https://github.com/kivy/buildozer/pull/969) ([misl6](https://github.com/misl6))
- Rename final apk with arch in the name [\#967](https://github.com/kivy/buildozer/pull/967) ([tito](https://github.com/tito))
- Code improvements around NDK download [\#961](https://github.com/kivy/buildozer/pull/961) ([inclement](https://github.com/inclement))
- Separate build per android.arch [\#957](https://github.com/kivy/buildozer/pull/957) ([tito](https://github.com/tito))
- spec file: cast paths in source.exclude\_dirs to lowercase [\#956](https://github.com/kivy/buildozer/pull/956) ([SomberNight](https://github.com/SomberNight))
- added cmake to requirements [\#950](https://github.com/kivy/buildozer/pull/950) ([mcroni](https://github.com/mcroni))
- Add ability to get p4a's recommended android's NDK version [\#947](https://github.com/kivy/buildozer/pull/947) ([opacam](https://github.com/opacam))
- New feature: allow to use a p4a fork [\#940](https://github.com/kivy/buildozer/pull/940) ([opacam](https://github.com/opacam))
- Minor linter fix [\#937](https://github.com/kivy/buildozer/pull/937) ([AndreMiras](https://github.com/AndreMiras))
- Update installation.rst [\#936](https://github.com/kivy/buildozer/pull/936) ([yairlempert](https://github.com/yairlempert))
- clarify overriding of config tokens [\#935](https://github.com/kivy/buildozer/pull/935) ([brentpicasso](https://github.com/brentpicasso))
- Extend add\_libs to arm64-v8a [\#934](https://github.com/kivy/buildozer/pull/934) ([misl6](https://github.com/misl6))
- Doc/installation updates [\#932](https://github.com/kivy/buildozer/pull/932) ([tshirtman](https://github.com/tshirtman))
- customizability options [\#919](https://github.com/kivy/buildozer/pull/919) ([zworkb](https://github.com/zworkb))
- disable orientation and window option for service\_only bootstrap [\#912](https://github.com/kivy/buildozer/pull/912) ([zworkb](https://github.com/zworkb))
- Unit test unicode decode on command output, fixes \#857 [\#905](https://github.com/kivy/buildozer/pull/905) ([AndreMiras](https://github.com/AndreMiras))
- Made sure to print all lines of license question by always flushing [\#904](https://github.com/kivy/buildozer/pull/904) ([inclement](https://github.com/inclement))
- Exits with error code on build exception, fixes \#674 [\#882](https://github.com/kivy/buildozer/pull/882) ([AndreMiras](https://github.com/AndreMiras))
- Download Apache ANT at the same path as the buildozer.spec android.ant\_path option [\#860](https://github.com/kivy/buildozer/pull/860) ([robertpro](https://github.com/robertpro))
- Fix for bug when logcat value which cannot be decode to utf-8 [\#856](https://github.com/kivy/buildozer/pull/856) ([Draqun](https://github.com/Draqun))
- Changes default log level to debug \(2\) [\#855](https://github.com/kivy/buildozer/pull/855) ([AndreMiras](https://github.com/AndreMiras))
- Handles unknown command/target error gracefully, closes \#812 [\#853](https://github.com/kivy/buildozer/pull/853) ([AndreMiras](https://github.com/AndreMiras))
- Updates system requirements needed to build recipes [\#852](https://github.com/kivy/buildozer/pull/852) ([AndreMiras](https://github.com/AndreMiras))
- Various Dockerfile improvements [\#848](https://github.com/kivy/buildozer/pull/848) ([AndreMiras](https://github.com/AndreMiras))
- Support p4a uses-library argument [\#846](https://github.com/kivy/buildozer/pull/846) ([pax0r](https://github.com/pax0r))
- Removed reference to Kivy VM [\#845](https://github.com/kivy/buildozer/pull/845) ([Megalex42](https://github.com/Megalex42))
- Removes extra log\_env\(\) call [\#843](https://github.com/kivy/buildozer/pull/843) ([AndreMiras](https://github.com/AndreMiras))
- add missing android arch to spec file [\#839](https://github.com/kivy/buildozer/pull/839) ([OptimusGREEN](https://github.com/OptimusGREEN))
- feat: make unzip quiet [\#836](https://github.com/kivy/buildozer/pull/836) ([mkg20001](https://github.com/mkg20001))
- fix: drop release-unsigned from release output path [\#835](https://github.com/kivy/buildozer/pull/835) ([mkg20001](https://github.com/mkg20001))
- Add ci\_mode to toggle download progress [\#833](https://github.com/kivy/buildozer/pull/833) ([mkg20001](https://github.com/mkg20001))
- Unit test logger [\#831](https://github.com/kivy/buildozer/pull/831) ([AndreMiras](https://github.com/AndreMiras))
- refactor auto accept license [\#822](https://github.com/kivy/buildozer/pull/822) ([AndreMiras](https://github.com/AndreMiras))
- Unit tests buildozer --help command, refs \#813 [\#821](https://github.com/kivy/buildozer/pull/821) ([AndreMiras](https://github.com/AndreMiras))
- Use getbooldefault\(\) for boolean, fixes \#806 [\#817](https://github.com/kivy/buildozer/pull/817) ([AndreMiras](https://github.com/AndreMiras))
- Update the issue template [\#814](https://github.com/kivy/buildozer/pull/814) ([AndreMiras](https://github.com/AndreMiras))
- Show envs when run2 [\#802](https://github.com/kivy/buildozer/pull/802) ([maho](https://github.com/maho))

## [0.39](https://github.com/kivy/buildozer/tree/0.39) (2019-02-04)
[Full Changelog](https://github.com/kivy/buildozer/compare/0.38...0.39)

## [0.38](https://github.com/kivy/buildozer/tree/0.38) (2019-02-03)
[Full Changelog](https://github.com/kivy/buildozer/compare/0.36...0.38)

**Fixed bugs:**

- TypeError: read\(\) takes exactly 2 arguments \(3 given\) [\#793](https://github.com/kivy/buildozer/issues/793)
- TypeError: read\(\) takes exactly 2 arguments \(3 given\) [\#792](https://github.com/kivy/buildozer/issues/792)
- AttributeError: 'str' object has no attribute 'decode' [\#756](https://github.com/kivy/buildozer/issues/756)

**Closed issues:**

- Openssl compilation fails, '\_\_atomic' undefined [\#800](https://github.com/kivy/buildozer/issues/800)
- --ndk-api appears twice [\#798](https://github.com/kivy/buildozer/issues/798)
- Error in toolchain.py and argument --ndk-api 9 [\#797](https://github.com/kivy/buildozer/issues/797)
- Target ndk-api is 19, but the \*\*python3 recipe supports only 21\*\* [\#796](https://github.com/kivy/buildozer/issues/796)
- Add support for --frameworks on iOS [\#790](https://github.com/kivy/buildozer/issues/790)
- Hello World impossible: checking whether the C compiler works... no [\#785](https://github.com/kivy/buildozer/issues/785)
- Buildozer 0.37 UnicodeDecodeError: 'ascii' codec can't decode byte 0xc2  [\#782](https://github.com/kivy/buildozer/issues/782)
- APK Crashes on start with no obvious cause [\#779](https://github.com/kivy/buildozer/issues/779)
- Outdated Android NDK download URL in Kivy Virtual Machine [\#778](https://github.com/kivy/buildozer/issues/778)
- Buildozer "gradlew failed!" [\#777](https://github.com/kivy/buildozer/issues/777)
- Conflicting documentation Python2 versus Python3 [\#774](https://github.com/kivy/buildozer/issues/774)
- No valid --ndk-api received, using the default of 0 = min\(android-api=0, default ndk-api=21\) [\#772](https://github.com/kivy/buildozer/issues/772)
- `default.spec` specifies `python3` but also incompatible NDK and API settings [\#770](https://github.com/kivy/buildozer/issues/770)
- Error: minsdk argument does not match the api that is compiled against [\#768](https://github.com/kivy/buildozer/issues/768)
- Need to support sensorLandscape [\#762](https://github.com/kivy/buildozer/issues/762)
- minsdk argument does not match the api that is compiled against [\#761](https://github.com/kivy/buildozer/issues/761)
- Need to be able to specify the NDK API target [\#758](https://github.com/kivy/buildozer/issues/758)
- Buildozer cannot import name pythran\_is\_numpy\_func\_supported  [\#753](https://github.com/kivy/buildozer/issues/753)
- Python3 recipe not building, error with self.ctx.python\_recipe [\#752](https://github.com/kivy/buildozer/issues/752)
- compile error [\#744](https://github.com/kivy/buildozer/issues/744)
- APK build failed "ndk\_platform doesn't exist" \(Python3.6; android.api = 27\) [\#742](https://github.com/kivy/buildozer/issues/742)
- Logo Design Proposal [\#734](https://github.com/kivy/buildozer/issues/734)
- `android clean` not working \(FileNotFoundError: \[Errno 2\] No such file or directory\) [\#732](https://github.com/kivy/buildozer/issues/732)
- Can't Make an APK via Buildozer [\#712](https://github.com/kivy/buildozer/issues/712)
- App build Failed [\#707](https://github.com/kivy/buildozer/issues/707)
- ERROR: /home/kivy/.buildozer/android/platform/apache-ant-1.9.4/bin/ant failed! [\#706](https://github.com/kivy/buildozer/issues/706)
- APK using txt file in main.py issue. [\#704](https://github.com/kivy/buildozer/issues/704)
- "Copying APK" fails because of wrong path used [\#699](https://github.com/kivy/buildozer/issues/699)
- Cannot build [\#697](https://github.com/kivy/buildozer/issues/697)
- Fail on build [\#692](https://github.com/kivy/buildozer/issues/692)
- Cannot build "Hello World" APK [\#687](https://github.com/kivy/buildozer/issues/687)
- Error when building an android APK using Kivy [\#684](https://github.com/kivy/buildozer/issues/684)
- can't get audio stream from a server [\#683](https://github.com/kivy/buildozer/issues/683)
- Continuous integration testing [\#679](https://github.com/kivy/buildozer/issues/679)
- Post build fails because copying built apk fails [\#671](https://github.com/kivy/buildozer/issues/671)
- Buildozer can't compile for Android on Manjaro Linux [\#670](https://github.com/kivy/buildozer/issues/670)
- Icon/Logo Proposal [\#669](https://github.com/kivy/buildozer/issues/669)
- Buildozer cant compile platform Ubuntu 16.04 [\#668](https://github.com/kivy/buildozer/issues/668)
- Buildozer gets stuck at unpacking kivy [\#667](https://github.com/kivy/buildozer/issues/667)
- Kivy window [\#666](https://github.com/kivy/buildozer/issues/666)
- Failed building wheel for pyaudio [\#665](https://github.com/kivy/buildozer/issues/665)
- Buildozer compilation gets stuck [\#663](https://github.com/kivy/buildozer/issues/663)
- IOError: \[Errno 2\] No such file or directory: u'/home/samurai-girl/python2/.buildozer/android/platform/build/dists/test/build/outputs/apk/test-debug.apk' [\#662](https://github.com/kivy/buildozer/issues/662)
- Unable to build \_ctypes.so [\#660](https://github.com/kivy/buildozer/issues/660)
- error while packaging for android on macOS [\#659](https://github.com/kivy/buildozer/issues/659)
- Command failed: /usr/bin/python2 -m pythonforandroid.toolchain [\#658](https://github.com/kivy/buildozer/issues/658)
- Cannot build apk with buildozer android debug [\#656](https://github.com/kivy/buildozer/issues/656)
- How to correctly build an APK package with Python 3? [\#655](https://github.com/kivy/buildozer/issues/655)
- SDK does not have any Build Tools installed. [\#652](https://github.com/kivy/buildozer/issues/652)
- Error building Kivy app with opencv\(and numpy\) - raise CommandNotFoundError\(path\) [\#651](https://github.com/kivy/buildozer/issues/651)
- FileNotFoundError: \[Errno 2\] [\#649](https://github.com/kivy/buildozer/issues/649)
-  The python3crystax recipe can only be built when using the CrystaX NDK. Exiting. [\#648](https://github.com/kivy/buildozer/issues/648)
- build apk : error can not find the build/output folder [\#647](https://github.com/kivy/buildozer/issues/647)
- help me building cryptography [\#646](https://github.com/kivy/buildozer/issues/646)
- sslv3 alert handshake failure on Addroid [\#643](https://github.com/kivy/buildozer/issues/643)
- Opening Android SDK Manager to download "Google Repository" and "Google Play services" [\#642](https://github.com/kivy/buildozer/issues/642)
- kivy python host failed [\#641](https://github.com/kivy/buildozer/issues/641)
- python.host failed [\#640](https://github.com/kivy/buildozer/issues/640)
- Kivy Crashing [\#638](https://github.com/kivy/buildozer/issues/638)
- .so lib files missing debug symbols [\#637](https://github.com/kivy/buildozer/issues/637)
- Kivy app doesn't run [\#634](https://github.com/kivy/buildozer/issues/634)
- "\* daemon not running. starting it now on port 5037 \* \* daemon started successfully \*" [\#633](https://github.com/kivy/buildozer/issues/633)
- FileNotFoundError: \[Errno 2\] No such file or directory: '/home/alex/Documents/pengame/.buildozer/android/platform/build/dists/helloworldapp/build/outputs/apk/helloworldapp-debug.apk' [\#632](https://github.com/kivy/buildozer/issues/632)
- Compiling Kivy app to apk fails with a pip error [\#631](https://github.com/kivy/buildozer/issues/631)
-  ERROR: /home/ubuntu/.buildozer/android/platform/apache-ant-1.9.4/bin/ant failed! [\#625](https://github.com/kivy/buildozer/issues/625)
- Build error when building Kivy app [\#624](https://github.com/kivy/buildozer/issues/624)
- buildozer debug is not running  this error is showing  [\#622](https://github.com/kivy/buildozer/issues/622)
- unexpected e\_machine: 3 [\#621](https://github.com/kivy/buildozer/issues/621)
- buildozer matplotlib [\#617](https://github.com/kivy/buildozer/issues/617)
- IOError: \[Errno 2\] No such file or directory: u'/Users/gauravgupta/kivy/.buildozer/android/platform/build/dists/myellipse/build/outputs/apk/myellipse-debug.apk' [\#613](https://github.com/kivy/buildozer/issues/613)
- Build failing in final ANT stage [\#610](https://github.com/kivy/buildozer/issues/610)
- Cannot build apk [\#606](https://github.com/kivy/buildozer/issues/606)
- Installing buildozer for Python 3 failed [\#604](https://github.com/kivy/buildozer/issues/604)
- FileNotFoundError at end of build when copying APK file. [\#602](https://github.com/kivy/buildozer/issues/602)
- BUILD FAILED [\#601](https://github.com/kivy/buildozer/issues/601)
- Error with buildozer [\#591](https://github.com/kivy/buildozer/issues/591)
- ImportError: No module named Cython.Distutils While running buildozer android debug [\#587](https://github.com/kivy/buildozer/issues/587)
- python 2.7 compile with NDK 15c [\#584](https://github.com/kivy/buildozer/issues/584)
- Problem upgrade to newest version [\#583](https://github.com/kivy/buildozer/issues/583)
- Simple Kivy test app can't compile to android apk [\#581](https://github.com/kivy/buildozer/issues/581)
- Apple Watch Support [\#574](https://github.com/kivy/buildozer/issues/574)
- Skip error or better error message: requirements with extra comma [\#562](https://github.com/kivy/buildozer/issues/562)
- failed to build numpy on Mac [\#557](https://github.com/kivy/buildozer/issues/557)
- p4a.source\_dir set and android clean --\> crash [\#556](https://github.com/kivy/buildozer/issues/556)
- Kivy python android build error? [\#555](https://github.com/kivy/buildozer/issues/555)
- python3 import networkx needs lib2to3 but cannot be imported [\#554](https://github.com/kivy/buildozer/issues/554)
- buildozer android debug deploy run ERROR [\#550](https://github.com/kivy/buildozer/issues/550)
- App Crashes [\#541](https://github.com/kivy/buildozer/issues/541)
- Requirements: Requests, Ssl [\#539](https://github.com/kivy/buildozer/issues/539)
- Error: Aidl cannot be executed [\#532](https://github.com/kivy/buildozer/issues/532)
- Kivy and Beautifulsoup with Buildozer fail on Python 3. [\#529](https://github.com/kivy/buildozer/issues/529)
- I'm having similar problem  [\#528](https://github.com/kivy/buildozer/issues/528)
- Awkward error while building apk [\#526](https://github.com/kivy/buildozer/issues/526)
- The "android" command is deprecated [\#519](https://github.com/kivy/buildozer/issues/519)
- Kivy: Permission denied \(when running buildozer android on Mac OS X\) [\#517](https://github.com/kivy/buildozer/issues/517)
- Extraction of "Kivy2.7z" failed [\#516](https://github.com/kivy/buildozer/issues/516)
- buildozer still download ndk from wrong path [\#506](https://github.com/kivy/buildozer/issues/506)
- android-new landscape error on restart [\#482](https://github.com/kivy/buildozer/issues/482)
- Add possibility to choose pip version for modules in the requirements section [\#475](https://github.com/kivy/buildozer/issues/475)
- Bulldozer android\_new fails when ffmpeg is added to the requirements: No C Compiler found! [\#463](https://github.com/kivy/buildozer/issues/463)
- CalledProcessError: Command '\['python', 'package\_app.py', '--displayname=Music Favorites'\]' returned non-zero exit status 1 [\#448](https://github.com/kivy/buildozer/issues/448)
- \[Errno 13\] Permission denied; Buildozer on Flask Server [\#445](https://github.com/kivy/buildozer/issues/445)
- Error while compiling a kivy app for android \(undefined reference to 'SDL\_main' collect2: error: ld returned 1 exit status\) [\#438](https://github.com/kivy/buildozer/issues/438)
- AsyncImage not loading in .apk [\#433](https://github.com/kivy/buildozer/issues/433)
- Big Bug, ORMs cant find sqlite3.so [\#426](https://github.com/kivy/buildozer/issues/426)
- cp: cannot stat '~/.buildozer/android/platform/python-for-android/src/libs/armeabi/\*.so': No such file or directory [\#422](https://github.com/kivy/buildozer/issues/422)
- using android\_new causes missing packages errors [\#420](https://github.com/kivy/buildozer/issues/420)
- Buildozer fails with "Command '\['ant', 'debug'\]' returned non-zero exit status 1" [\#419](https://github.com/kivy/buildozer/issues/419)
- Buildozer fails to build when ffmpeg is added  [\#418](https://github.com/kivy/buildozer/issues/418)
- Build on arm64 android [\#412](https://github.com/kivy/buildozer/issues/412)
- Building with "android\_new" target fails due to missing architecture on pythonforandroid.toolchain apk [\#407](https://github.com/kivy/buildozer/issues/407)
- Command '\['ant', 'debug'\]' returned non-zero exit status 1 when building PIL library [\#406](https://github.com/kivy/buildozer/issues/406)
- Android, Pygame backend: buildozer android debug deploy run tries to launch wrong Activity [\#401](https://github.com/kivy/buildozer/issues/401)
- AttributeError: 'NoneType' object has no attribute 'splitlines' [\#400](https://github.com/kivy/buildozer/issues/400)
- Pyzmq import fails on Android with python2 / kivy 1.9 / cython 0.23 [\#397](https://github.com/kivy/buildozer/issues/397)
- Python 3: \# Aidl cannot be executed AttributeError: 'module' object has no attribute 'maxint' [\#392](https://github.com/kivy/buildozer/issues/392)
- subprocess.CalledProcessError [\#391](https://github.com/kivy/buildozer/issues/391)
- python.host could not find platform independent libraries [\#390](https://github.com/kivy/buildozer/issues/390)
- Buildozer android\_new fails [\#388](https://github.com/kivy/buildozer/issues/388)
- toolchain.py: error: argument --private is required [\#384](https://github.com/kivy/buildozer/issues/384)
- Android fails on running Kivy apk [\#381](https://github.com/kivy/buildozer/issues/381)
- ImportError: No module named plyer with android\_new as a target [\#379](https://github.com/kivy/buildozer/issues/379)
- buildozer -v android debug runs into problem [\#376](https://github.com/kivy/buildozer/issues/376)
- subprocess.CalledProcessError [\#372](https://github.com/kivy/buildozer/issues/372)
- Can't install Pillow , return errors [\#371](https://github.com/kivy/buildozer/issues/371)
- failed to load ctypes as android app built on OSX [\#368](https://github.com/kivy/buildozer/issues/368)
- old\_toolchain not shows images [\#367](https://github.com/kivy/buildozer/issues/367)
- Buildozer deployment dlopen failed libSDL2.so has unexpected e\_machine: 40 [\#365](https://github.com/kivy/buildozer/issues/365)
- Rebuild only selected packages [\#226](https://github.com/kivy/buildozer/issues/226)

**Merged pull requests:**

- Updated README for Python 3 [\#809](https://github.com/kivy/buildozer/pull/809) ([inclement](https://github.com/inclement))
- Update README.md to add opencollective [\#808](https://github.com/kivy/buildozer/pull/808) ([tito](https://github.com/tito))
- Made buildozer respect user sdk dir when accessing sdkmanager [\#807](https://github.com/kivy/buildozer/pull/807) ([inclement](https://github.com/inclement))
- Removed android\_old and updated SDK management to work with current SDK [\#806](https://github.com/kivy/buildozer/pull/806) ([inclement](https://github.com/inclement))
- Removed redundant --ndk-api argument and fixed default value [\#805](https://github.com/kivy/buildozer/pull/805) ([inclement](https://github.com/inclement))
- Update for p4a master [\#803](https://github.com/kivy/buildozer/pull/803) ([inclement](https://github.com/inclement))
- Unit tests read spec file, refs \#793 [\#799](https://github.com/kivy/buildozer/pull/799) ([AndreMiras](https://github.com/AndreMiras))
- Support the --add-frameworks flag in kivy-ios [\#795](https://github.com/kivy/buildozer/pull/795) ([hackalog](https://github.com/hackalog))
- Introduces CI and tox testing, fixes \#679 [\#794](https://github.com/kivy/buildozer/pull/794) ([AndreMiras](https://github.com/AndreMiras))
- Fix python 2 crash when reading config file [\#791](https://github.com/kivy/buildozer/pull/791) ([etc0de](https://github.com/etc0de))
- Handle buildozer.spec with unicode chars [\#789](https://github.com/kivy/buildozer/pull/789) ([guysoft](https://github.com/guysoft))
- Specify GitHub branches in buildozer.spec [\#787](https://github.com/kivy/buildozer/pull/787) ([hackalog](https://github.com/hackalog))
- Fixes minor comment typo introduced in \#759 [\#786](https://github.com/kivy/buildozer/pull/786) ([AndreMiras](https://github.com/AndreMiras))
- Docker from current git [\#775](https://github.com/kivy/buildozer/pull/775) ([maho](https://github.com/maho))
- Fix output directory for gradle [\#766](https://github.com/kivy/buildozer/pull/766) ([wo01](https://github.com/wo01))
- support sensorLandscape mode. resolves \#762 [\#763](https://github.com/kivy/buildozer/pull/763) ([brentpicasso](https://github.com/brentpicasso))
- allow specifying of Android NDK API. Resolves \#758 [\#759](https://github.com/kivy/buildozer/pull/759) ([brentpicasso](https://github.com/brentpicasso))
- Update cython version from the docs [\#757](https://github.com/kivy/buildozer/pull/757) ([AndreMiras](https://github.com/AndreMiras))
- fix android sdk/ndk information link [\#755](https://github.com/kivy/buildozer/pull/755) ([avere001](https://github.com/avere001))
- this allows to build with ndk 17c \(and other recent-ish ones\) [\#754](https://github.com/kivy/buildozer/pull/754) ([tshirtman](https://github.com/tshirtman))
- fix ndk URLs [\#747](https://github.com/kivy/buildozer/pull/747) ([zworkb](https://github.com/zworkb))

## [0.36](https://github.com/kivy/buildozer/tree/0.36) (2018-11-21)
[Full Changelog](https://github.com/kivy/buildozer/compare/0.35...0.36)

**Fixed bugs:**

- Error in debug, install platform, Indexerror. [\#731](https://github.com/kivy/buildozer/issues/731)

**Closed issues:**

- Buildozer looking for nonexistent script [\#749](https://github.com/kivy/buildozer/issues/749)
- Can not build APK file with buildozer. UnicodeDecodeError [\#746](https://github.com/kivy/buildozer/issues/746)
- CrystaX no longer the preferred NDK for Python3 [\#745](https://github.com/kivy/buildozer/issues/745)
- AKP build fails \(android.py line 524\) [\#738](https://github.com/kivy/buildozer/issues/738)
- Buildozer 0.35 with IndexError: list index out of range on Mac OS [\#737](https://github.com/kivy/buildozer/issues/737)
- cannot build pyjnius for armeabi-v7a [\#735](https://github.com/kivy/buildozer/issues/735)
- I can't package my app the way i always did. [\#733](https://github.com/kivy/buildozer/issues/733)
- OSError: \[Errno 18\] Invalid cross-device link [\#644](https://github.com/kivy/buildozer/issues/644)

**Merged pull requests:**

- Correctly write out a sub-process's `stdout` when using Python 3. [\#743](https://github.com/kivy/buildozer/pull/743) ([dbrnz](https://github.com/dbrnz))
- Explicitly run `pip3` when using Python 3 [\#741](https://github.com/kivy/buildozer/pull/741) ([dbrnz](https://github.com/dbrnz))
- workaround for working in WSL [\#740](https://github.com/kivy/buildozer/pull/740) ([tshirtman](https://github.com/tshirtman))
- Allow for `install\_reqs` line having whitespace at start. [\#736](https://github.com/kivy/buildozer/pull/736) ([dbrnz](https://github.com/dbrnz))
- Fix Support config file name [\#730](https://github.com/kivy/buildozer/pull/730) ([dessant](https://github.com/dessant))

## [0.35](https://github.com/kivy/buildozer/tree/0.35) (2018-10-24)
[Full Changelog](https://github.com/kivy/buildozer/compare/0.34...0.35)

**Fixed bugs:**

- Buildozer should not regex/hack install\_reqs [\#722](https://github.com/kivy/buildozer/issues/722)

**Closed issues:**

- Command failed: /usr/bin/python -m pythonforandroid.toolchain create...  [\#727](https://github.com/kivy/buildozer/issues/727)
- buildozer fails at installing platfrom [\#726](https://github.com/kivy/buildozer/issues/726)
- Unable to build APK [\#725](https://github.com/kivy/buildozer/issues/725)
- Buildozer APK not working: OS X, Docker, or fresh Ubuntu 16.04 [\#723](https://github.com/kivy/buildozer/issues/723)
- gcc Segmentation Fault [\#720](https://github.com/kivy/buildozer/issues/720)
- Error debugging for android [\#719](https://github.com/kivy/buildozer/issues/719)
- ndk\_platform doesn't exist \(when switching to API = 28\) [\#717](https://github.com/kivy/buildozer/issues/717)
- FileNotFoundError: \[Errno 2\] \(SOLVED\) - It was Encoding Error [\#715](https://github.com/kivy/buildozer/issues/715)
- SDL\_JAVA\_PACKAGE\_PATH error? [\#714](https://github.com/kivy/buildozer/issues/714)
- Python3Crystax instructions in README [\#710](https://github.com/kivy/buildozer/issues/710)
- Bug or support request? [\#708](https://github.com/kivy/buildozer/issues/708)
- build requirement failed [\#701](https://github.com/kivy/buildozer/issues/701)
- I am using Virtual Machine provided in the official kivy website for building android APK, this is the part of log file [\#696](https://github.com/kivy/buildozer/issues/696)
- App minimizes instantly after launching.  [\#695](https://github.com/kivy/buildozer/issues/695)
- Aidl not detected [\#694](https://github.com/kivy/buildozer/issues/694)
- python 3 ssl [\#690](https://github.com/kivy/buildozer/issues/690)
- Is there something like multiprocessing? [\#685](https://github.com/kivy/buildozer/issues/685)
- Kivy in pyCharm  [\#682](https://github.com/kivy/buildozer/issues/682)
- Toolchain error. Help,please! [\#678](https://github.com/kivy/buildozer/issues/678)
- virtual machine does not compile apk Fails with errors [\#677](https://github.com/kivy/buildozer/issues/677)
- An error in Buildozer Apk \(Python Kivy\) Help PLZ! [\#676](https://github.com/kivy/buildozer/issues/676)
- App crashes on android but works fine in idle window using buildozer [\#675](https://github.com/kivy/buildozer/issues/675)
- Pyjnius exception Adbuddiz class not found [\#661](https://github.com/kivy/buildozer/issues/661)
- Buildozer failed to execute the last command \#/usr/bin/python3 -m pythonforandroid.toolchain create --dist\_name=blueb --bootstrap=sdl2 --requirements=python3crystax,kivy --arch x86 --copy-libs --color=always --storage-dir=/home/jp/Desktop/BlueB/.buildozer/android/platform/build [\#654](https://github.com/kivy/buildozer/issues/654)
- java.lang.ClassNotFoundException: sun.misc.BASE64Encoder	 [\#639](https://github.com/kivy/buildozer/issues/639)
- IOError: \[Errno 2\] No such file or directory: [\#636](https://github.com/kivy/buildozer/issues/636)
- App crashes with aws boto3 [\#635](https://github.com/kivy/buildozer/issues/635)
- APK Immediately Closes After Opening in Debug, Release, and Zipaligned & Signed Versions [\#629](https://github.com/kivy/buildozer/issues/629)
- Using Python/Buildozer to compile Kivy for Android [\#628](https://github.com/kivy/buildozer/issues/628)
- "configure: error: C compiler cannot create executables See `config.log' for more details" \(\# Command failed: ./distribute.sh -m "kivy" -d "pollygot"\) [\#627](https://github.com/kivy/buildozer/issues/627)
- "OSError: \[Errno 30\] Read-only file system" \(\# Command failed: virtualenv --python=python2.7 ./venv\) [\#626](https://github.com/kivy/buildozer/issues/626)
- Java compiling issue: buildozer uses obsolete source value 1.5 [\#619](https://github.com/kivy/buildozer/issues/619)
- Cloning into 'python-for-android-new-toolchain'... [\#618](https://github.com/kivy/buildozer/issues/618)
- Failed to build application: 'WindowInfoX11' is not a type identifier [\#616](https://github.com/kivy/buildozer/issues/616)
- Sudo issue\[closed\] [\#615](https://github.com/kivy/buildozer/issues/615)
- buildozer-vm-2 installed from scratch ABENDS [\#611](https://github.com/kivy/buildozer/issues/611)
- ASCII decode problem [\#608](https://github.com/kivy/buildozer/issues/608)
- error: could not delete 'build/lib.linux-x86\_64-2.7/buildozer/targets/android.py': Permission denied [\#607](https://github.com/kivy/buildozer/issues/607)
- APK Build Failing with Python 3.6 [\#605](https://github.com/kivy/buildozer/issues/605)
- IOError: \[Errno 2\] No such file or directory: u'/home/kivy/buildozer/.buildozer/android/platform/build/... [\#603](https://github.com/kivy/buildozer/issues/603)
- Feature Request: Dockerfile or image in dockerhub [\#589](https://github.com/kivy/buildozer/issues/589)
- Buildozer debug error. [\#545](https://github.com/kivy/buildozer/issues/545)

**Merged pull requests:**

- Fix \#645 [\#729](https://github.com/kivy/buildozer/pull/729) ([tito](https://github.com/tito))
- Enable Support app [\#728](https://github.com/kivy/buildozer/pull/728) ([dessant](https://github.com/dessant))
- Updates p4a deps parsing [\#724](https://github.com/kivy/buildozer/pull/724) ([AndreMiras](https://github.com/AndreMiras))
- Improved error handling if p4a setup.py can't be read [\#721](https://github.com/kivy/buildozer/pull/721) ([inclement](https://github.com/inclement))
- Various spelling corrections [\#718](https://github.com/kivy/buildozer/pull/718) ([Zen-CODE](https://github.com/Zen-CODE))
- Updates Python 3 install instructions, fixes \#710 [\#711](https://github.com/kivy/buildozer/pull/711) ([AndreMiras](https://github.com/AndreMiras))
- Remove obsolete sh package dependency [\#705](https://github.com/kivy/buildozer/pull/705) ([Cheaterman](https://github.com/Cheaterman))
- Changes how is\_gradle\_build is detected. [\#700](https://github.com/kivy/buildozer/pull/700) ([rammie](https://github.com/rammie))
- Cleans installation docs [\#689](https://github.com/kivy/buildozer/pull/689) ([AndreMiras](https://github.com/AndreMiras))
- Adds issue template with basic required info [\#688](https://github.com/kivy/buildozer/pull/688) ([AndreMiras](https://github.com/AndreMiras))
- buildozer Dockerfile, fixes \#589 [\#681](https://github.com/kivy/buildozer/pull/681) ([AndreMiras](https://github.com/AndreMiras))
- Removes few unused variables [\#680](https://github.com/kivy/buildozer/pull/680) ([AndreMiras](https://github.com/AndreMiras))
- Fixed a typo pointed out by AndreMiras [\#664](https://github.com/kivy/buildozer/pull/664) ([inclement](https://github.com/inclement))
- Updates installation.rst with Ubuntu 18.04 instructions [\#657](https://github.com/kivy/buildozer/pull/657) ([AndreMiras](https://github.com/AndreMiras))
- fix prerelease version [\#653](https://github.com/kivy/buildozer/pull/653) ([marceloneil](https://github.com/marceloneil))
- allow setting launchMode for the main activity in the manifest [\#650](https://github.com/kivy/buildozer/pull/650) ([SomberNight](https://github.com/SomberNight))
- Fixes Invalid cross-device link [\#645](https://github.com/kivy/buildozer/pull/645) ([robertpro](https://github.com/robertpro))
- Quote --storage-dir value [\#630](https://github.com/kivy/buildozer/pull/630) ([ghost](https://github.com/ghost))
- Allow adding Java activities to the manifest [\#612](https://github.com/kivy/buildozer/pull/612) ([bauerj](https://github.com/bauerj))
- add comment re p4a.port in default.spec [\#600](https://github.com/kivy/buildozer/pull/600) ([replabrobin](https://github.com/replabrobin))
- Spelling [\#592](https://github.com/kivy/buildozer/pull/592) ([jsoref](https://github.com/jsoref))

## [0.34](https://github.com/kivy/buildozer/tree/0.34) (2017-12-15)
[Full Changelog](https://github.com/kivy/buildozer/compare/0.33...0.34)

**Closed issues:**

- IOERROR invalid directory [\#599](https://github.com/kivy/buildozer/issues/599)
- Buidozer 0.33  AttributeError: 'module' object has no attribute 'directory' [\#598](https://github.com/kivy/buildozer/issues/598)
- Issu with buildozer packing [\#596](https://github.com/kivy/buildozer/issues/596)
- Gradle: path may not be null or empty string. path='null' [\#595](https://github.com/kivy/buildozer/issues/595)
- ERROR: Trying to release a package that starts with org.test; what can I do? [\#593](https://github.com/kivy/buildozer/issues/593)
- App crash with python3 [\#590](https://github.com/kivy/buildozer/issues/590)
- Problem running buildozer android debug first time [\#586](https://github.com/kivy/buildozer/issues/586)
- buildozer download some content failed [\#585](https://github.com/kivy/buildozer/issues/585)
- complie platform failed [\#580](https://github.com/kivy/buildozer/issues/580)
- Module OS - buildozer.spec [\#579](https://github.com/kivy/buildozer/issues/579)
- Buildozer doesn't compile app with cryptography requirement [\#578](https://github.com/kivy/buildozer/issues/578)
- Buildozer x psycopg2 [\#575](https://github.com/kivy/buildozer/issues/575)
- Problem with Android  API 23 [\#573](https://github.com/kivy/buildozer/issues/573)
- App crashing on startup- ImportError: dlopen failed: \_imaging.so is 64-bit [\#568](https://github.com/kivy/buildozer/issues/568)
- Buildozer issue with latest Xcode/macOS [\#566](https://github.com/kivy/buildozer/issues/566)
- Requests SSL error [\#565](https://github.com/kivy/buildozer/issues/565)
- buildozer failed for `Broken toolchain` when building numpy with python.host [\#564](https://github.com/kivy/buildozer/issues/564)
- Encountered a bad program behavior [\#563](https://github.com/kivy/buildozer/issues/563)
- error at using pycypto in the requirements [\#558](https://github.com/kivy/buildozer/issues/558)
-  Websocket error: SSL not available. [\#552](https://github.com/kivy/buildozer/issues/552)
- "crystax\_python does not exist" with python3crystax [\#551](https://github.com/kivy/buildozer/issues/551)
- App crashes after build [\#549](https://github.com/kivy/buildozer/issues/549)
- Installing CyLP on windows [\#548](https://github.com/kivy/buildozer/issues/548)
- Service notification launch intent causes app crash [\#547](https://github.com/kivy/buildozer/issues/547)
- Application crashes on start [\#546](https://github.com/kivy/buildozer/issues/546)
- New android target is unable to produce a python 4 android service [\#543](https://github.com/kivy/buildozer/issues/543)
- Buildozer Build Error [\#538](https://github.com/kivy/buildozer/issues/538)
- \# Aidl not found, please install it. [\#537](https://github.com/kivy/buildozer/issues/537)
- Error compiling Cython file on Ubuntu 14.0.4 with python 2.7 and 3.4/5  [\#536](https://github.com/kivy/buildozer/issues/536)
- Failed compilation on ubuntu with python 2.7 configure: error: C compiler cannot create executables [\#535](https://github.com/kivy/buildozer/issues/535)
- Remove app permissions added by default [\#534](https://github.com/kivy/buildozer/issues/534)
- Buildozer error while packaging [\#531](https://github.com/kivy/buildozer/issues/531)
- Buildozer failing to pack .apk  [\#530](https://github.com/kivy/buildozer/issues/530)
- toolchain fails to recognize option --sdk [\#524](https://github.com/kivy/buildozer/issues/524)
- \# Command failed: /usr/bin/python -m pythonforandroid.toolchain create --dist\_name=myapp --bootstrap=sdl2 --requirements=kivy --arch armeabi-v7a --copy-libs --color=always --storage-dir=/home/abhipso/thembapp/.buildozer/android/platform/build [\#521](https://github.com/kivy/buildozer/issues/521)
- apk way too large - 800mb [\#520](https://github.com/kivy/buildozer/issues/520)
- \[features\] Snapcraft implementation [\#514](https://github.com/kivy/buildozer/issues/514)
- Possibility of building in kivy virtual machine all locally [\#513](https://github.com/kivy/buildozer/issues/513)
- Python3\(crystax ndk\) builds broken [\#511](https://github.com/kivy/buildozer/issues/511)
- build fails in virtualenv [\#509](https://github.com/kivy/buildozer/issues/509)
- password for the virtual machine? [\#507](https://github.com/kivy/buildozer/issues/507)
- Failed to build APK with python 3.6 : \[sh.CommandNotFound: python3.5\] [\#504](https://github.com/kivy/buildozer/issues/504)
- Don't Unpacking opencv for armeabi-v7a [\#503](https://github.com/kivy/buildozer/issues/503)
- Fails to package app on OSX Sierra 10.12.4 \(hdiutil: attach failed - image not recognized keka\) [\#494](https://github.com/kivy/buildozer/issues/494)
- File missing building release APK  [\#469](https://github.com/kivy/buildozer/issues/469)
- Building APK using Buildozer/Kivy [\#459](https://github.com/kivy/buildozer/issues/459)
- buildozer failed to build apk: subprocess.CalledProcessError: Command '\['ant', 'debug'\]' returned non-zero exit status 1 [\#373](https://github.com/kivy/buildozer/issues/373)
- AttributeError: 'Context' object has no attribute 'hostpython' in recipe [\#361](https://github.com/kivy/buildozer/issues/361)
- Cant compile apk with sqlite3 \(using python3 crystax\) [\#359](https://github.com/kivy/buildozer/issues/359)

**Merged pull requests:**

- Imported os to fix ImportError [\#594](https://github.com/kivy/buildozer/pull/594) ([inclement](https://github.com/inclement))
- add p4a.port config option; to allow specifiying webview port [\#588](https://github.com/kivy/buildozer/pull/588) ([replabrobin](https://github.com/replabrobin))
- Fix Py3 utf-8 encode error [\#582](https://github.com/kivy/buildozer/pull/582) ([Zen-CODE](https://github.com/Zen-CODE))
- Fixes `p4a.branch` comment [\#577](https://github.com/kivy/buildozer/pull/577) ([AndreMiras](https://github.com/AndreMiras))
- Fix old toolchain index error [\#576](https://github.com/kivy/buildozer/pull/576) ([Zen-CODE](https://github.com/Zen-CODE))
- Some fixes in old android target [\#572](https://github.com/kivy/buildozer/pull/572) ([rnixx](https://github.com/rnixx))
- Removed --sdk argument for p4a [\#571](https://github.com/kivy/buildozer/pull/571) ([inclement](https://github.com/inclement))
- Update specifications.rst [\#560](https://github.com/kivy/buildozer/pull/560) ([crajun](https://github.com/crajun))
- Changed p4a directory name for current toolchain [\#527](https://github.com/kivy/buildozer/pull/527) ([inclement](https://github.com/inclement))
- Update android.py, updated recreate the project.properties section [\#525](https://github.com/kivy/buildozer/pull/525) ([mokhoo](https://github.com/mokhoo))
- Fix unicode coding error in android build target [\#518](https://github.com/kivy/buildozer/pull/518) ([jamalex](https://github.com/jamalex))
- Add 404 status code handling on kivy download [\#508](https://github.com/kivy/buildozer/pull/508) ([SecretObsession](https://github.com/SecretObsession))
- Use dmg instead of 7z [\#505](https://github.com/kivy/buildozer/pull/505) ([shivan1b](https://github.com/shivan1b))

## [0.33](https://github.com/kivy/buildozer/tree/0.33) (2017-05-15)
[Full Changelog](https://github.com/kivy/buildozer/compare/v0.32...0.33)

**Fixed bugs:**

- Installation of python for android is missing dependencies [\#501](https://github.com/kivy/buildozer/issues/501)

**Closed issues:**

- Break buildozer if the user try to release a version with "org.test" as a domain [\#500](https://github.com/kivy/buildozer/issues/500)
- Migrate p4a options to its own subkey [\#499](https://github.com/kivy/buildozer/issues/499)
- Use stable branch from python-for-android [\#498](https://github.com/kivy/buildozer/issues/498)
- Migrate android to android\_new, and add android\_old [\#497](https://github.com/kivy/buildozer/issues/497)
- sh.CommandNotFound: cmake [\#496](https://github.com/kivy/buildozer/issues/496)
- Need Help Fatal signal 11 \(SIGSEGV\) at 0x00000000 \(code=1\), thread 4579 \(SDLThread\) [\#495](https://github.com/kivy/buildozer/issues/495)
- Buildozer APK Cannot LAUNCH [\#493](https://github.com/kivy/buildozer/issues/493)
- Buildozer Error [\#492](https://github.com/kivy/buildozer/issues/492)
- android\_new target hardcodes python2 support for p4a [\#491](https://github.com/kivy/buildozer/issues/491)
- android.arch ignored [\#488](https://github.com/kivy/buildozer/issues/488)
- fail to install distribute [\#486](https://github.com/kivy/buildozer/issues/486)
- sh.py raise a exception and fail to build [\#485](https://github.com/kivy/buildozer/issues/485)
- some functionality lost when debugged with android\_new command [\#481](https://github.com/kivy/buildozer/issues/481)
- Problem when deploy to android device [\#480](https://github.com/kivy/buildozer/issues/480)
- dlopen failed: python2.7/site-packages/grpc/\_cython/cygrpc.so not 32-bit: 2 [\#479](https://github.com/kivy/buildozer/issues/479)
- Cannot build APK with python3crystax and flask - conflicting dependencies [\#477](https://github.com/kivy/buildozer/issues/477)
- Buildozer can't download NDK [\#474](https://github.com/kivy/buildozer/issues/474)
- websocket-client "SSL not available." [\#473](https://github.com/kivy/buildozer/issues/473)
- Using Cython with Kivy-iOS and Buildozer [\#472](https://github.com/kivy/buildozer/issues/472)
- android.requirements does not merge with app.requirements [\#471](https://github.com/kivy/buildozer/issues/471)
- buildozer fails to find Android SDK [\#468](https://github.com/kivy/buildozer/issues/468)
- Crash of APK on start [\#467](https://github.com/kivy/buildozer/issues/467)
- App not launching [\#461](https://github.com/kivy/buildozer/issues/461)
- sqlite3 not working with android\_new [\#457](https://github.com/kivy/buildozer/issues/457)
- how to set path for p4a [\#454](https://github.com/kivy/buildozer/issues/454)
- TypeError: write\(\) argument 1 must be unicode, not str [\#452](https://github.com/kivy/buildozer/issues/452)
- New toolchain - lxml included but not able to import [\#451](https://github.com/kivy/buildozer/issues/451)
- sqlite3 with python2.7 and buildozer 0.33dev and new toolchain not working [\#450](https://github.com/kivy/buildozer/issues/450)
- Update the Virtual Machine @ https://kivy.org/\#download [\#449](https://github.com/kivy/buildozer/issues/449)
- “No module named setuptools” after installing setuptools [\#444](https://github.com/kivy/buildozer/issues/444)
- how to add  --arch=armeabi-v7a to buildozer spec [\#443](https://github.com/kivy/buildozer/issues/443)
- `buildozer android debug` fails with `jinja2.exceptions.TemplateNotFound: build.xml` [\#442](https://github.com/kivy/buildozer/issues/442)
- buildozer.spec - requirements - kivy == master [\#440](https://github.com/kivy/buildozer/issues/440)
- Buildozer can't find zlib [\#437](https://github.com/kivy/buildozer/issues/437)
- Expose kivy download source? [\#435](https://github.com/kivy/buildozer/issues/435)
- compiling crash [\#431](https://github.com/kivy/buildozer/issues/431)
- Buildozer unable to make apk [\#430](https://github.com/kivy/buildozer/issues/430)
- Crash APK on start [\#429](https://github.com/kivy/buildozer/issues/429)
- More like a noob question [\#428](https://github.com/kivy/buildozer/issues/428)
- keka failed to download \(OS X El Capitan\) [\#427](https://github.com/kivy/buildozer/issues/427)
- Buildozer fails with pure python library pint [\#425](https://github.com/kivy/buildozer/issues/425)
- Invalid argument to arm-linux-androideabi-gcc [\#424](https://github.com/kivy/buildozer/issues/424)
- dlopen failed: \_clock.so is 64-bit instead of 32-bit [\#423](https://github.com/kivy/buildozer/issues/423)
- how to solve the build error for "java"? [\#421](https://github.com/kivy/buildozer/issues/421)
- Problems in patching files during building for android\_new [\#416](https://github.com/kivy/buildozer/issues/416)
- Buildozer doesn't work with multiple first-class directories [\#415](https://github.com/kivy/buildozer/issues/415)
- Buildozer suddenly not working, Linux, Python 2.7 \(build.xml: Failed to find version-tag string\) [\#414](https://github.com/kivy/buildozer/issues/414)
- Buildozer not finding aidl [\#413](https://github.com/kivy/buildozer/issues/413)
- buildozer android created apk fails if application source kept in multiple files [\#411](https://github.com/kivy/buildozer/issues/411)
- Python 3 unicode print \(\) / copy to clipboard crashes app on Android [\#404](https://github.com/kivy/buildozer/issues/404)
- checking whether the C compiler works... no [\#402](https://github.com/kivy/buildozer/issues/402)
- configure: error: C compiler cannot create executables [\#395](https://github.com/kivy/buildozer/issues/395)
-  ConfigParser.NoOptionError: No option 'p4a.local\_recipes' in section: 'app' \(android\_new\) [\#394](https://github.com/kivy/buildozer/issues/394)
- Google has changed the type of archive the new NDK [\#393](https://github.com/kivy/buildozer/issues/393)
- Why does buildozer build and pull python for android from old\_toolchain branch ? [\#389](https://github.com/kivy/buildozer/issues/389)
- buildozer android\_new does not show the presplash [\#387](https://github.com/kivy/buildozer/issues/387)
- Error when using buildozer android\_new with python3crystax [\#386](https://github.com/kivy/buildozer/issues/386)
- Command failed: tar xzf android-sdk\_r20-linux.tgz [\#383](https://github.com/kivy/buildozer/issues/383)
- When will you add requests lib to recipes? [\#382](https://github.com/kivy/buildozer/issues/382)
- Presplash does not work with "android\_new" as target. [\#380](https://github.com/kivy/buildozer/issues/380)
- Build for Android is Inconsistent with the Linux Version  [\#378](https://github.com/kivy/buildozer/issues/378)
- \[question\] What are the supported OS ? [\#369](https://github.com/kivy/buildozer/issues/369)
- AttributeError: 'AnsiCodes' object has no attribute 'LIGHTBLUE\_EX' [\#366](https://github.com/kivy/buildozer/issues/366)
- splash image not hide after kivy loaded [\#364](https://github.com/kivy/buildozer/issues/364)
- app always crash in android [\#360](https://github.com/kivy/buildozer/issues/360)
- Plyer not available in buildozer android\_new [\#358](https://github.com/kivy/buildozer/issues/358)
- Runs empty directory instead of binary \(android\_new\) [\#357](https://github.com/kivy/buildozer/issues/357)
- App built with buildozer does not open on android [\#356](https://github.com/kivy/buildozer/issues/356)
- Error when running buildozer android\_new debug [\#354](https://github.com/kivy/buildozer/issues/354)
- ios list\_identities returns no identities [\#353](https://github.com/kivy/buildozer/issues/353)
- buildozer not working [\#350](https://github.com/kivy/buildozer/issues/350)
- error: Cython does not appear to be installed [\#349](https://github.com/kivy/buildozer/issues/349)
- AttributeError: 'Context' object has no attribute 'hostpython' [\#347](https://github.com/kivy/buildozer/issues/347)
- osx packaging results in venv error [\#345](https://github.com/kivy/buildozer/issues/345)
- Requirement example requirements = kivy,requests fails [\#344](https://github.com/kivy/buildozer/issues/344)
- Unavailability of important packages [\#343](https://github.com/kivy/buildozer/issues/343)
- no way to change bootstrap [\#341](https://github.com/kivy/buildozer/issues/341)
- Apk built with buildozer and multiple python file crashes [\#331](https://github.com/kivy/buildozer/issues/331)
- Please upgrade the documentation [\#255](https://github.com/kivy/buildozer/issues/255)
- Buildozer doesn't recognize "profile" option anymore [\#254](https://github.com/kivy/buildozer/issues/254)
- Try to build with caldav requirement fails [\#248](https://github.com/kivy/buildozer/issues/248)
- Trouble building for older android versions [\#240](https://github.com/kivy/buildozer/issues/240)
- removing old apk file seems to fail before installing the new one [\#238](https://github.com/kivy/buildozer/issues/238)
- Build fails due to python-distribute.org being down [\#200](https://github.com/kivy/buildozer/issues/200)
- I am struggling with building an apk [\#153](https://github.com/kivy/buildozer/issues/153)
- fresh android sdk install requires sdk update [\#151](https://github.com/kivy/buildozer/issues/151)
- FYI - Ubuntu 14.04 Necessary Java Path Adjustment [\#141](https://github.com/kivy/buildozer/issues/141)
- Cannot compile `iri2uri.py` in `httplib2` [\#135](https://github.com/kivy/buildozer/issues/135)
- can't add django to requirement [\#130](https://github.com/kivy/buildozer/issues/130)
- add an ssh target [\#1](https://github.com/kivy/buildozer/issues/1)

**Merged pull requests:**

- close \#452 as suggested by SpotlightKid [\#489](https://github.com/kivy/buildozer/pull/489) ([pat1](https://github.com/pat1))
- Update README.rst [\#487](https://github.com/kivy/buildozer/pull/487) ([matletix](https://github.com/matletix))
- Made buildozer run p4a using the current sys.executable [\#484](https://github.com/kivy/buildozer/pull/484) ([inclement](https://github.com/inclement))
- ios: refactor deprecated PackageApplication command [\#483](https://github.com/kivy/buildozer/pull/483) ([kived](https://github.com/kived))
- android\_new: change skip\_update to skip all updates [\#465](https://github.com/kivy/buildozer/pull/465) ([ZingBallyhoo](https://github.com/ZingBallyhoo))
- android\_new: add "android.arch" config option [\#458](https://github.com/kivy/buildozer/pull/458) ([ZingBallyhoo](https://github.com/ZingBallyhoo))
- Fix Py3 Incompatable str + bytes issue. [\#456](https://github.com/kivy/buildozer/pull/456) ([FeralBytes](https://github.com/FeralBytes))
- spec file: dont use fullscreen by default [\#447](https://github.com/kivy/buildozer/pull/447) ([rafalo1333](https://github.com/rafalo1333))
- spec file: use portrait orientation by default [\#446](https://github.com/kivy/buildozer/pull/446) ([rafalo1333](https://github.com/rafalo1333))
- Add presplash background color support for android\_new toolchain [\#436](https://github.com/kivy/buildozer/pull/436) ([rnixx](https://github.com/rnixx))
- Fix file\_matches to never return None [\#432](https://github.com/kivy/buildozer/pull/432) ([inclement](https://github.com/inclement))
- Fixed 64 bit detection \(it failed under python3\) [\#409](https://github.com/kivy/buildozer/pull/409) ([inclement](https://github.com/inclement))
- Added p4a.local\_recipes to default.spec and handled its absence [\#405](https://github.com/kivy/buildozer/pull/405) ([inclement](https://github.com/inclement))
- Adding README.rst entries for how to use buildozer with python3 [\#403](https://github.com/kivy/buildozer/pull/403) ([andyDoucette](https://github.com/andyDoucette))
- Update installation.rst \(Ubuntu16.04\) [\#399](https://github.com/kivy/buildozer/pull/399) ([FermiParadox](https://github.com/FermiParadox))
- Update quickstart.rst [\#398](https://github.com/kivy/buildozer/pull/398) ([FermiParadox](https://github.com/FermiParadox))
- Add p4a.local\_recipes to buildozer.spec to specify a local recipe dir… [\#385](https://github.com/kivy/buildozer/pull/385) ([cidermole](https://github.com/cidermole))
- Always pass required args to p4a in android\_new [\#375](https://github.com/kivy/buildozer/pull/375) ([inclement](https://github.com/inclement))
- Changed p4a command order to work with argparse [\#374](https://github.com/kivy/buildozer/pull/374) ([inclement](https://github.com/inclement))
- buildozer has no attribute builddir [\#351](https://github.com/kivy/buildozer/pull/351) ([nilutz](https://github.com/nilutz))
- throw error early if running in venv [\#346](https://github.com/kivy/buildozer/pull/346) ([kived](https://github.com/kived))
- allow selection of bootstrap for android\_new [\#342](https://github.com/kivy/buildozer/pull/342) ([kived](https://github.com/kived))
- bump version to 0.33dev [\#340](https://github.com/kivy/buildozer/pull/340) ([kived](https://github.com/kived))
- trying to fix Kivy install for OS X builds [\#316](https://github.com/kivy/buildozer/pull/316) ([derPinguin](https://github.com/derPinguin))
- update installation info [\#256](https://github.com/kivy/buildozer/pull/256) ([kiok46](https://github.com/kiok46))

## [v0.32](https://github.com/kivy/buildozer/tree/v0.32) (2016-05-09)
[Full Changelog](https://github.com/kivy/buildozer/compare/v0.31...v0.32)

**Closed issues:**

- When is the support coming to build windows .exe using buildozer? [\#333](https://github.com/kivy/buildozer/issues/333)
- outdated openssl [\#332](https://github.com/kivy/buildozer/issues/332)
- ios deployment fails \(buildozer --verbose ios debug deploy\) [\#330](https://github.com/kivy/buildozer/issues/330)
- Can't add uuid pytz datetime time dbf to requirements [\#329](https://github.com/kivy/buildozer/issues/329)
- AttributeError: 'NoneType' object has no attribute 'startswith' [\#326](https://github.com/kivy/buildozer/issues/326)
- android.p4a\_dir use old toolchain? [\#325](https://github.com/kivy/buildozer/issues/325)
- Switch from pygame to sdl2 easily [\#313](https://github.com/kivy/buildozer/issues/313)
- IOError: \[Errno 2\] No such file or directory: "/home/andrew/CODE/Python/kivy-test-android/.buildozer/android/platform/python-for-android/dist/helloworld/bin/HelloWorld-'1.0'-debug.apk" [\#312](https://github.com/kivy/buildozer/issues/312)
- Marshmallow sdk not found [\#310](https://github.com/kivy/buildozer/issues/310)
- Install Buildozer: Finished processing dependencies for buildozer==0.32dev [\#304](https://github.com/kivy/buildozer/issues/304)
- Bump default min SDK to 13: Fix crash on orientation change bug [\#302](https://github.com/kivy/buildozer/issues/302)
- Disable "Open with file manager" when USB cable is connected in virtual machine [\#299](https://github.com/kivy/buildozer/issues/299)
- Check presence of main.py during build time [\#298](https://github.com/kivy/buildozer/issues/298)
- Py3: 'Buildozer' object has no attribute 'critical' [\#297](https://github.com/kivy/buildozer/issues/297)
- The splash screen isn't automatically resized [\#292](https://github.com/kivy/buildozer/issues/292)
- buildozer don't work if whitespace in path [\#287](https://github.com/kivy/buildozer/issues/287)
- buildozer help fail [\#285](https://github.com/kivy/buildozer/issues/285)
- Buildozer.spec 's title of your application can not be a Chinese character [\#284](https://github.com/kivy/buildozer/issues/284)
- How to build apk with a cython file [\#283](https://github.com/kivy/buildozer/issues/283)
- pip no longer has a --download-cache option, so downloading requirements has stopped working [\#279](https://github.com/kivy/buildozer/issues/279)
- Cython2 not recognized in Fedora23 ? [\#278](https://github.com/kivy/buildozer/issues/278)
- Buildozer VIrtual Machine Error: /jni/application/src/': Not a directory [\#277](https://github.com/kivy/buildozer/issues/277)
- buildozer android debug deploy run hangs [\#275](https://github.com/kivy/buildozer/issues/275)
- Is it possible to move the .buildozer folder somewhere else? [\#273](https://github.com/kivy/buildozer/issues/273)
- configure: error: C compiler cannot create executables [\#272](https://github.com/kivy/buildozer/issues/272)
- buildozer deploy error [\#271](https://github.com/kivy/buildozer/issues/271)
- Cannot set Android API version [\#268](https://github.com/kivy/buildozer/issues/268)
- Support python3 [\#265](https://github.com/kivy/buildozer/issues/265)
- App crash when changing orientation [\#264](https://github.com/kivy/buildozer/issues/264)
- Broken update command [\#261](https://github.com/kivy/buildozer/issues/261)
- error while deploying android  [\#257](https://github.com/kivy/buildozer/issues/257)
-  jnius/jnius.c: No such file or directory [\#251](https://github.com/kivy/buildozer/issues/251)
- Implement source.include\_patterns [\#245](https://github.com/kivy/buildozer/issues/245)
- Buildozer Python 3 Compatability Issues [\#175](https://github.com/kivy/buildozer/issues/175)

**Merged pull requests:**

- prepare for release 0.32 [\#339](https://github.com/kivy/buildozer/pull/339) ([kived](https://github.com/kived))
- use p4a --color argument [\#338](https://github.com/kivy/buildozer/pull/338) ([kived](https://github.com/kived))
- fix changing android branch [\#337](https://github.com/kivy/buildozer/pull/337) ([kived](https://github.com/kived))
- use cp -a not cp -r [\#336](https://github.com/kivy/buildozer/pull/336) ([akshayaurora](https://github.com/akshayaurora))
- improve build directory handling, add values to default.spec [\#335](https://github.com/kivy/buildozer/pull/335) ([kived](https://github.com/kived))
- fix incorrect api/minapi values [\#334](https://github.com/kivy/buildozer/pull/334) ([kived](https://github.com/kived))
- fix bad placement of expanduser\(\) [\#328](https://github.com/kivy/buildozer/pull/328) ([kived](https://github.com/kived))
- use custom source dirs for android\_new [\#324](https://github.com/kivy/buildozer/pull/324) ([kived](https://github.com/kived))
- use p4a revamp --storage-dir option [\#323](https://github.com/kivy/buildozer/pull/323) ([kived](https://github.com/kived))
- add adb and p4a commands to android/android\_new [\#322](https://github.com/kivy/buildozer/pull/322) ([kived](https://github.com/kived))
- fix py3 str has no decode issue [\#321](https://github.com/kivy/buildozer/pull/321) ([kived](https://github.com/kived))
- let p4a revamp handle pure python requirements [\#320](https://github.com/kivy/buildozer/pull/320) ([kived](https://github.com/kived))
- fix icons for ios target [\#319](https://github.com/kivy/buildozer/pull/319) ([kived](https://github.com/kived))
- support using custom kivy-ios source dir [\#318](https://github.com/kivy/buildozer/pull/318) ([kived](https://github.com/kived))
- disable bitcode for ios target [\#317](https://github.com/kivy/buildozer/pull/317) ([kived](https://github.com/kived))
- Add window option for target android\_new [\#315](https://github.com/kivy/buildozer/pull/315) ([pythonic64](https://github.com/pythonic64))
- fix usage exception [\#311](https://github.com/kivy/buildozer/pull/311) ([kived](https://github.com/kived))
- add python3 compatibility to verbose output for android build \(\#221\) [\#303](https://github.com/kivy/buildozer/pull/303) ([pohmelie](https://github.com/pohmelie))
- Allow app title to contain Unicode characters [\#293](https://github.com/kivy/buildozer/pull/293) ([udiboy1209](https://github.com/udiboy1209))
- use ios-deploy version 1.7.0 [\#291](https://github.com/kivy/buildozer/pull/291) ([cbenhagen](https://github.com/cbenhagen))
- Add spec option to skip automated update of installed android package [\#290](https://github.com/kivy/buildozer/pull/290) ([pastcompute](https://github.com/pastcompute))
- Fix issues with android.p4a\_dir spec file property [\#288](https://github.com/kivy/buildozer/pull/288) ([pastcompute](https://github.com/pastcompute))
- Remove pip --download-cache flag \(fixes \#279\) [\#282](https://github.com/kivy/buildozer/pull/282) ([cbenhagen](https://github.com/cbenhagen))
- put bin/ in builddir if specified in buildozer.spec [\#274](https://github.com/kivy/buildozer/pull/274) ([jabbalaci](https://github.com/jabbalaci))
- Implement source.include\_patterns [\#269](https://github.com/kivy/buildozer/pull/269) ([udiboy1209](https://github.com/udiboy1209))
- Updated Licence Year [\#266](https://github.com/kivy/buildozer/pull/266) ([CodeMaxx](https://github.com/CodeMaxx))
- fix android.branch option [\#250](https://github.com/kivy/buildozer/pull/250) ([tshirtman](https://github.com/tshirtman))

## [v0.31](https://github.com/kivy/buildozer/tree/v0.31) (2016-01-07)
[Full Changelog](https://github.com/kivy/buildozer/compare/0.30...v0.31)

**Closed issues:**

- Logo aspect ratio problem [\#263](https://github.com/kivy/buildozer/issues/263)
- Is there a way to seperate building environment and building apk? [\#259](https://github.com/kivy/buildozer/issues/259)
- buildozer must be ran with sudo [\#258](https://github.com/kivy/buildozer/issues/258)
- Invalid NDK platform [\#253](https://github.com/kivy/buildozer/issues/253)
- Q:compile error [\#252](https://github.com/kivy/buildozer/issues/252)
- Please update SDK url [\#249](https://github.com/kivy/buildozer/issues/249)
- java.lang.NoSuchMethodException: isSupportChangeBadgeByCallMethod \[\] [\#243](https://github.com/kivy/buildozer/issues/243)
- AttributeError: 'NoneType' object has no attribute 'group' [\#242](https://github.com/kivy/buildozer/issues/242)
- Error: Flag '-a' is not valid for 'list sdk'. [\#241](https://github.com/kivy/buildozer/issues/241)
- Provide custom path for android SDK to buildozer [\#237](https://github.com/kivy/buildozer/issues/237)
- kivy examples seem to need \_\_version\_\_ [\#236](https://github.com/kivy/buildozer/issues/236)
- pyliblo [\#235](https://github.com/kivy/buildozer/issues/235)

**Merged pull requests:**

- OS X Target for Bulldozer [\#262](https://github.com/kivy/buildozer/pull/262) ([akshayaurora](https://github.com/akshayaurora))
- kill easy\_install [\#244](https://github.com/kivy/buildozer/pull/244) ([techtonik](https://github.com/techtonik))
- install requires virtualenv [\#239](https://github.com/kivy/buildozer/pull/239) ([cbenhagen](https://github.com/cbenhagen))
- Fixed Space in app path issue. Fixes \#13 [\#231](https://github.com/kivy/buildozer/pull/231) ([dvenkatsagar](https://github.com/dvenkatsagar))

## [0.30](https://github.com/kivy/buildozer/tree/0.30) (2015-10-04)
[Full Changelog](https://github.com/kivy/buildozer/compare/v0.29...0.30)

**Closed issues:**

- subprocess.CalledProcessError: Command '\['ant', 'debug'\]' returned non-zero exit status 1 [\#234](https://github.com/kivy/buildozer/issues/234)
- Cannot use numpy with buildozer [\#232](https://github.com/kivy/buildozer/issues/232)
- Problem downloading ndk version \> r9d [\#229](https://github.com/kivy/buildozer/issues/229)
- Error likely to missing 32 bit packages [\#228](https://github.com/kivy/buildozer/issues/228)
- Bulldozer can't download new ndks 10x... [\#227](https://github.com/kivy/buildozer/issues/227)
- Error while trying to install Buildozer in Windows  10 [\#225](https://github.com/kivy/buildozer/issues/225)
- Making reverse engineering .apk harder [\#224](https://github.com/kivy/buildozer/issues/224)
- Buildozer wont compile libraries with cython 0.23 or 0.22 [\#223](https://github.com/kivy/buildozer/issues/223)
- These are the errors I get when I try to package the file...  [\#222](https://github.com/kivy/buildozer/issues/222)
- Buildozer installs platform despite setting ndk & sdk paths [\#220](https://github.com/kivy/buildozer/issues/220)
- Can't find config.ini buildozer solution [\#219](https://github.com/kivy/buildozer/issues/219)
- Ant error: SDK does not have any Build Tools installed [\#218](https://github.com/kivy/buildozer/issues/218)
- Buildozer fails because of build-tools package name [\#217](https://github.com/kivy/buildozer/issues/217)
- ImportError: No module named pygments [\#216](https://github.com/kivy/buildozer/issues/216)
- buildozer android camera [\#215](https://github.com/kivy/buildozer/issues/215)
- Error when first time Building apk   [\#212](https://github.com/kivy/buildozer/issues/212)
- cannot import name spawnu [\#211](https://github.com/kivy/buildozer/issues/211)
- Buildozer recompiles p4a when a custom for of plyer is used. [\#210](https://github.com/kivy/buildozer/issues/210)
- Add android.ant\_path to default.spec [\#209](https://github.com/kivy/buildozer/issues/209)
- Problems with adding wav, ogg and ttf files [\#208](https://github.com/kivy/buildozer/issues/208)
- cython issue with kivy and buildozer development versions [\#207](https://github.com/kivy/buildozer/issues/207)
- subprocess.CalledProcessError: Command '\['ant', 'debug'\]' returned non-zero exit status 1 [\#205](https://github.com/kivy/buildozer/issues/205)
- Buildozer isn't building if I try to include some requirements [\#195](https://github.com/kivy/buildozer/issues/195)
- Cant build APK for android.api = 10 [\#193](https://github.com/kivy/buildozer/issues/193)
- Doc error: "buildozer clean" does not exist [\#189](https://github.com/kivy/buildozer/issues/189)
- Can't install pillow requirement [\#188](https://github.com/kivy/buildozer/issues/188)
- \#error from Cython compilation [\#150](https://github.com/kivy/buildozer/issues/150)
- Space in app path path name causes ./distribute -m kivy to fail [\#13](https://github.com/kivy/buildozer/issues/13)

**Merged pull requests:**

- Changed p4a download to pull old\_toolchain branch [\#233](https://github.com/kivy/buildozer/pull/233) ([inclement](https://github.com/inclement))
- Added support for downloading and handling android ndk r10 versions. Fixes \#229 and \#227 [\#230](https://github.com/kivy/buildozer/pull/230) ([dvenkatsagar](https://github.com/dvenkatsagar))
- make \_read\_version\_subdir return parse\('0'\) instead of \[0\], otherwise… [\#206](https://github.com/kivy/buildozer/pull/206) ([denys-duchier](https://github.com/denys-duchier))

## [v0.29](https://github.com/kivy/buildozer/tree/v0.29) (2015-06-01)
[Full Changelog](https://github.com/kivy/buildozer/compare/v0.27...v0.29)

**Fixed bugs:**

- version problem with split [\#201](https://github.com/kivy/buildozer/issues/201)

**Closed issues:**

- buildozer android release hangs at "compile platform" [\#199](https://github.com/kivy/buildozer/issues/199)
- Hang up at Fetching https://dl-ssl.google.com/android/repository/addons\_list-2.xml [\#198](https://github.com/kivy/buildozer/issues/198)
- Python 3 Import error on urllib.request. [\#187](https://github.com/kivy/buildozer/issues/187)

**Merged pull requests:**

- needs testing, should fix \#201 using pypa implementation of PEP440 [\#202](https://github.com/kivy/buildozer/pull/202) ([tshirtman](https://github.com/tshirtman))
- check for complete dist instead of dist dir [\#197](https://github.com/kivy/buildozer/pull/197) ([kived](https://github.com/kived))
- fix ios targets xcode command [\#194](https://github.com/kivy/buildozer/pull/194) ([cbenhagen](https://github.com/cbenhagen))
- Windows fix [\#192](https://github.com/kivy/buildozer/pull/192) ([jaynakus](https://github.com/jaynakus))
- some python 3 compatibility [\#191](https://github.com/kivy/buildozer/pull/191) ([pohmelie](https://github.com/pohmelie))
- allow custom source folders in buildozer.spec [\#185](https://github.com/kivy/buildozer/pull/185) ([kived](https://github.com/kived))
- use upstream pexpect instead of shipping it [\#176](https://github.com/kivy/buildozer/pull/176) ([tshirtman](https://github.com/tshirtman))

## [v0.27](https://github.com/kivy/buildozer/tree/v0.27) (2015-03-08)
[Full Changelog](https://github.com/kivy/buildozer/compare/0.26...v0.27)

**Closed issues:**

- subprocess.CalledProcessError: Command '\['ant', 'debug'\]' returned non-zero exit status 1 [\#183](https://github.com/kivy/buildozer/issues/183)
- Buildozer get error during packaging for android [\#182](https://github.com/kivy/buildozer/issues/182)
- Bug with android.p4a\_whitelist in buildozer.spec file. [\#180](https://github.com/kivy/buildozer/issues/180)
- You need an option for git https [\#178](https://github.com/kivy/buildozer/issues/178)
- Buildozer .apk file creation issue [\#177](https://github.com/kivy/buildozer/issues/177)
- sudo buildozer Fails [\#174](https://github.com/kivy/buildozer/issues/174)
- Buildozer iOS Apps Won't Open [\#171](https://github.com/kivy/buildozer/issues/171)
- always show python-for-android output on failure [\#170](https://github.com/kivy/buildozer/issues/170)
- Buildozer tries to install android sdk every time you try to compile an android application. [\#169](https://github.com/kivy/buildozer/issues/169)
- automatic installation of android sdk fails due to unicode parsing error [\#166](https://github.com/kivy/buildozer/issues/166)
- Move from fruitstrap to ios-deploy [\#107](https://github.com/kivy/buildozer/issues/107)
- buildozer ios debug build fails on MacOS Mavericks [\#83](https://github.com/kivy/buildozer/issues/83)
- gdb doesn't work anymore with Xcode 5 [\#54](https://github.com/kivy/buildozer/issues/54)
- buildozer ios debug deploy fails on running fruitstrap at 70% with error AMDeviceInstallApplication failed [\#9](https://github.com/kivy/buildozer/issues/9)

**Merged pull requests:**

- fix black text in log [\#184](https://github.com/kivy/buildozer/pull/184) ([kived](https://github.com/kived))

## [0.26](https://github.com/kivy/buildozer/tree/0.26) (2015-01-28)
[Full Changelog](https://github.com/kivy/buildozer/compare/0.25...0.26)

**Merged pull requests:**

- ensure whitelist always has a list [\#172](https://github.com/kivy/buildozer/pull/172) ([kived](https://github.com/kived))

## [0.25](https://github.com/kivy/buildozer/tree/0.25) (2015-01-27)
[Full Changelog](https://github.com/kivy/buildozer/compare/0.24...0.25)

## [0.24](https://github.com/kivy/buildozer/tree/0.24) (2015-01-27)
[Full Changelog](https://github.com/kivy/buildozer/compare/0.23...0.24)

## [0.23](https://github.com/kivy/buildozer/tree/0.23) (2015-01-27)
[Full Changelog](https://github.com/kivy/buildozer/compare/0.22...0.23)

## [0.22](https://github.com/kivy/buildozer/tree/0.22) (2015-01-27)
[Full Changelog](https://github.com/kivy/buildozer/compare/v0.21...0.22)

## [v0.21](https://github.com/kivy/buildozer/tree/v0.21) (2015-01-14)
[Full Changelog](https://github.com/kivy/buildozer/compare/0.19...v0.21)

**Merged pull requests:**

- removed some indentation in example info, added to actual comments inste... [\#168](https://github.com/kivy/buildozer/pull/168) ([chozabu](https://github.com/chozabu))

## [0.19](https://github.com/kivy/buildozer/tree/0.19) (2014-12-17)
[Full Changelog](https://github.com/kivy/buildozer/compare/0.18...0.19)

## [0.18](https://github.com/kivy/buildozer/tree/0.18) (2014-12-17)
[Full Changelog](https://github.com/kivy/buildozer/compare/0.17...0.18)

**Closed issues:**

- buildozer can't download python libs due to ssl certificate check fail [\#164](https://github.com/kivy/buildozer/issues/164)
- Buildozer feature redirect .buildozer folder outside your project [\#162](https://github.com/kivy/buildozer/issues/162)
- Buildozer fails on clean build [\#161](https://github.com/kivy/buildozer/issues/161)
- pjnius build fails on Arch Linux when requiring netifaces [\#159](https://github.com/kivy/buildozer/issues/159)
- error compiling with buildozer [\#158](https://github.com/kivy/buildozer/issues/158)
- C compiler cannot create executables [\#152](https://github.com/kivy/buildozer/issues/152)
- Requirements needing commas instead of spaces \(like p4a\) is non-obvious [\#147](https://github.com/kivy/buildozer/issues/147)

**Merged pull requests:**

- fix build error and allow redirecting build folder [\#163](https://github.com/kivy/buildozer/pull/163) ([olymk2](https://github.com/olymk2))
- Remove duplicated checkbin\(\). [\#160](https://github.com/kivy/buildozer/pull/160) ([attakei](https://github.com/attakei))
- added note about buildozer not having anything to do with buildozer.io [\#157](https://github.com/kivy/buildozer/pull/157) ([nickyspag](https://github.com/nickyspag))
- Fixed logic to compare with “non installed” with “minor version upped"  [\#156](https://github.com/kivy/buildozer/pull/156) ([attakei](https://github.com/attakei))
- Set "UTF-8" to java file.encoding for android update command explicitly [\#155](https://github.com/kivy/buildozer/pull/155) ([attakei](https://github.com/attakei))
- added example to default.spec requirements showing comma seperation [\#148](https://github.com/kivy/buildozer/pull/148) ([chozabu](https://github.com/chozabu))

## [0.17](https://github.com/kivy/buildozer/tree/0.17) (2014-09-22)
[Full Changelog](https://github.com/kivy/buildozer/compare/0.16...0.17)

## [0.16](https://github.com/kivy/buildozer/tree/0.16) (2014-09-22)
[Full Changelog](https://github.com/kivy/buildozer/compare/0.15...0.16)

**Closed issues:**

- `install\_android\_packages` is too slow to run in china. [\#143](https://github.com/kivy/buildozer/issues/143)
- Buildozer setup.py fails with Module ImportError [\#140](https://github.com/kivy/buildozer/issues/140)
- buildozer downloads Android SDK 20 during every call to deploy app [\#137](https://github.com/kivy/buildozer/issues/137)
- Buildozerv0.15: lib/pexpect.py is not Python 3 compatable [\#131](https://github.com/kivy/buildozer/issues/131)
- Keep on gettting version error [\#129](https://github.com/kivy/buildozer/issues/129)
- arm-linux-androideabi-gcc: fatal error: no input files [\#127](https://github.com/kivy/buildozer/issues/127)
- I am new to python and buildozer, using buildozer to compile my first android app [\#125](https://github.com/kivy/buildozer/issues/125)
- I am new to python and buildozer, using buildozer to compile my first android app, [\#124](https://github.com/kivy/buildozer/issues/124)
- Command Failed [\#122](https://github.com/kivy/buildozer/issues/122)
- Exception: Cython cythonnot found [\#120](https://github.com/kivy/buildozer/issues/120)
- Enable use for packaging OSX apps [\#114](https://github.com/kivy/buildozer/issues/114)
- Errors on 'buildozer android debug deploy run' [\#113](https://github.com/kivy/buildozer/issues/113)
- Fail to download Android SDK in Linux and Python 3.3 [\#110](https://github.com/kivy/buildozer/issues/110)
- Unable to add "requirements" buildozer.spec [\#109](https://github.com/kivy/buildozer/issues/109)
- TypeError: 'encoding' is an invalid keyword argument for this function [\#106](https://github.com/kivy/buildozer/issues/106)
- Custom activity [\#33](https://github.com/kivy/buildozer/issues/33)
- Buildozer fails to install on Windows [\#27](https://github.com/kivy/buildozer/issues/27)
- support blacklist changes in python-for-android [\#17](https://github.com/kivy/buildozer/issues/17)

**Merged pull requests:**

- Test in file\_rename if target directory exists. [\#144](https://github.com/kivy/buildozer/pull/144) ([droundy](https://github.com/droundy))
- Fix for android.library\_references path issue [\#139](https://github.com/kivy/buildozer/pull/139) ([excessivedemon](https://github.com/excessivedemon))
- Specs doc revision [\#134](https://github.com/kivy/buildozer/pull/134) ([dessant](https://github.com/dessant))
- Make pexpect.py Python 3 Compatable [\#133](https://github.com/kivy/buildozer/pull/133) ([FeralBytes](https://github.com/FeralBytes))
- Added check for buildozer running as root [\#128](https://github.com/kivy/buildozer/pull/128) ([inclement](https://github.com/inclement))
- Add link to the right android python project [\#119](https://github.com/kivy/buildozer/pull/119) ([techtonik](https://github.com/techtonik))
- Execute buildozer as "python -m buildozer" [\#118](https://github.com/kivy/buildozer/pull/118) ([techtonik](https://github.com/techtonik))
- Fix \#115 [\#116](https://github.com/kivy/buildozer/pull/116) ([manuelbua](https://github.com/manuelbua))

## [0.15](https://github.com/kivy/buildozer/tree/0.15) (2014-06-02)
[Full Changelog](https://github.com/kivy/buildozer/compare/0.14...0.15)

**Closed issues:**

- Do not set permissions \(ug+x\) if already set [\#115](https://github.com/kivy/buildozer/issues/115)
- UTF-8 Encoding Error, \_\_init.py\_\_ 0.15-dev [\#108](https://github.com/kivy/buildozer/issues/108)
- incorrect minapi android manifest value [\#93](https://github.com/kivy/buildozer/issues/93)
- libpython wait4 linker error [\#92](https://github.com/kivy/buildozer/issues/92)
- fcntl import error [\#88](https://github.com/kivy/buildozer/issues/88)
- No Python 3 Support [\#84](https://github.com/kivy/buildozer/issues/84)
- Uncaught exception on missing cython [\#80](https://github.com/kivy/buildozer/issues/80)
- Where are custom python-for-android recipes meant to go? [\#76](https://github.com/kivy/buildozer/issues/76)
- Error compiling Cython file: [\#73](https://github.com/kivy/buildozer/issues/73)
- Zlib still giving issues on Ubuntu 13.04 [\#72](https://github.com/kivy/buildozer/issues/72)
- DBAccessError permission denied in app [\#71](https://github.com/kivy/buildozer/issues/71)
- Selective update of depencencies [\#70](https://github.com/kivy/buildozer/issues/70)
- 32-bit SDK installed on 64-bit system [\#69](https://github.com/kivy/buildozer/issues/69)
- wrong version regex [\#67](https://github.com/kivy/buildozer/issues/67)
- sdk update fails on license question [\#66](https://github.com/kivy/buildozer/issues/66)
- x86 and armeabi-v7 libs [\#63](https://github.com/kivy/buildozer/issues/63)
- Missing dependenced during compilation [\#59](https://github.com/kivy/buildozer/issues/59)
- Bad magic number when reading generated state.db file in VMware Ubuntu guest [\#42](https://github.com/kivy/buildozer/issues/42)
- x86 apk support on buildozer [\#11](https://github.com/kivy/buildozer/issues/11)

**Merged pull requests:**

- Ignore UTF-8 decoding errors. Closes \#108 [\#112](https://github.com/kivy/buildozer/pull/112) ([cbenhagen](https://github.com/cbenhagen))
- chmod ug+x android\_cmd [\#111](https://github.com/kivy/buildozer/pull/111) ([cbenhagen](https://github.com/cbenhagen))
- p4a whitelist [\#98](https://github.com/kivy/buildozer/pull/98) ([b3ni](https://github.com/b3ni))

## [0.14](https://github.com/kivy/buildozer/tree/0.14) (2014-04-20)
[Full Changelog](https://github.com/kivy/buildozer/compare/0.13...0.14)

## [0.13](https://github.com/kivy/buildozer/tree/0.13) (2014-04-20)
[Full Changelog](https://github.com/kivy/buildozer/compare/0.12...0.13)

## [0.12](https://github.com/kivy/buildozer/tree/0.12) (2014-04-20)
[Full Changelog](https://github.com/kivy/buildozer/compare/0.11...0.12)

## [0.11](https://github.com/kivy/buildozer/tree/0.11) (2014-04-20)
[Full Changelog](https://github.com/kivy/buildozer/compare/0.10...0.11)

**Closed issues:**

- Text provider [\#105](https://github.com/kivy/buildozer/issues/105)
- No installation instructions [\#104](https://github.com/kivy/buildozer/issues/104)

## [0.10](https://github.com/kivy/buildozer/tree/0.10) (2014-04-09)
[Full Changelog](https://github.com/kivy/buildozer/compare/0.9...0.10)

**Closed issues:**

- Android SDK installation not working anymore [\#101](https://github.com/kivy/buildozer/issues/101)
- Buildozer almost completes and then errors saying file exists [\#99](https://github.com/kivy/buildozer/issues/99)
- Java compilernot found [\#95](https://github.com/kivy/buildozer/issues/95)
- Absolute path problem [\#91](https://github.com/kivy/buildozer/issues/91)
- Error when running: buildozer --verbose android debug deploy run [\#89](https://github.com/kivy/buildozer/issues/89)
- buildozer.spec passing requirements  [\#87](https://github.com/kivy/buildozer/issues/87)
- debugging "Command failed" is tedious [\#86](https://github.com/kivy/buildozer/issues/86)
- No module named sqlite3  [\#56](https://github.com/kivy/buildozer/issues/56)
- Garden packages are unsupported [\#39](https://github.com/kivy/buildozer/issues/39)
- python-for-android repo is hard-coded in buildozer [\#37](https://github.com/kivy/buildozer/issues/37)
- virtualenv-2.7 hardcoded [\#22](https://github.com/kivy/buildozer/issues/22)
- Buildozer error no build.py [\#21](https://github.com/kivy/buildozer/issues/21)

**Merged pull requests:**

- Fixed garden install for newer virtualenvs [\#100](https://github.com/kivy/buildozer/pull/100) ([brousch](https://github.com/brousch))
- fix ln if soft link existed [\#96](https://github.com/kivy/buildozer/pull/96) ([pengjia](https://github.com/pengjia))
- Added realpath modifier to p4a\_dir token [\#94](https://github.com/kivy/buildozer/pull/94) ([inclement](https://github.com/inclement))
- Documented env var checking and fixed a bug in the p4a\_dir check [\#85](https://github.com/kivy/buildozer/pull/85) ([inclement](https://github.com/inclement))
- Delete dist dir if running distribute.sh [\#81](https://github.com/kivy/buildozer/pull/81) ([inclement](https://github.com/inclement))
- implement the `clean` command. [\#79](https://github.com/kivy/buildozer/pull/79) ([akshayaurora](https://github.com/akshayaurora))
- Garden requirements [\#41](https://github.com/kivy/buildozer/pull/41) ([Ian-Foote](https://github.com/Ian-Foote))

## [0.9](https://github.com/kivy/buildozer/tree/0.9) (2014-02-13)
[Full Changelog](https://github.com/kivy/buildozer/compare/0.8...0.9)

**Closed issues:**

-  Command failed: ./distribute.sh -m "kivy" error message [\#77](https://github.com/kivy/buildozer/issues/77)
- Error importing \_scproxy [\#68](https://github.com/kivy/buildozer/issues/68)
- Package names beginning with a number cause an obscure crash with an unclear error message [\#64](https://github.com/kivy/buildozer/issues/64)
- failing to compile sample android app with buildozer  [\#61](https://github.com/kivy/buildozer/issues/61)
- Default android.sdk setting causes sensor rotate on Android to fail [\#32](https://github.com/kivy/buildozer/issues/32)
- Add wakelock to options [\#31](https://github.com/kivy/buildozer/issues/31)

**Merged pull requests:**

- Updated Android NDK default version to 9c [\#82](https://github.com/kivy/buildozer/pull/82) ([brousch](https://github.com/brousch))
- Add 'bin' to suggested default directory excludes [\#78](https://github.com/kivy/buildozer/pull/78) ([joseph-jnl](https://github.com/joseph-jnl))
- Clarified wording in README [\#75](https://github.com/kivy/buildozer/pull/75) ([inclement](https://github.com/inclement))
- Check for package name starting with number [\#65](https://github.com/kivy/buildozer/pull/65) ([inclement](https://github.com/inclement))
- \[FIX\] Detect 32/64 bit on Windows, to download Android NDK [\#62](https://github.com/kivy/buildozer/pull/62) ([alanjds](https://github.com/alanjds))
- Added --private and --dir Android storage option [\#58](https://github.com/kivy/buildozer/pull/58) ([brousch](https://github.com/brousch))
- Added a 'serve' command to serve bin/ over SimpleHTTPServer [\#49](https://github.com/kivy/buildozer/pull/49) ([brousch](https://github.com/brousch))

## [0.8](https://github.com/kivy/buildozer/tree/0.8) (2013-10-29)
[Full Changelog](https://github.com/kivy/buildozer/compare/0.7...0.8)

**Fixed bugs:**

- \_patch\_application\_sources breaks from \_\_future\_\_ imports [\#35](https://github.com/kivy/buildozer/issues/35)

**Closed issues:**

- unresolved domain: pygame.org [\#34](https://github.com/kivy/buildozer/issues/34)

**Merged pull requests:**

- Add ability to choose python-for-android directory [\#60](https://github.com/kivy/buildozer/pull/60) ([inclement](https://github.com/inclement))
- Update default Android NDK to r9 [\#53](https://github.com/kivy/buildozer/pull/53) ([brousch](https://github.com/brousch))
- Added android.wakelock option [\#51](https://github.com/kivy/buildozer/pull/51) ([brousch](https://github.com/brousch))
- Fixed another 'Unknown' typo [\#48](https://github.com/kivy/buildozer/pull/48) ([brousch](https://github.com/brousch))
- Fixed spelling of 'Unknown' [\#47](https://github.com/kivy/buildozer/pull/47) ([brousch](https://github.com/brousch))
- Fixed missing 'r' on ANDROIDNDKVER environment export [\#46](https://github.com/kivy/buildozer/pull/46) ([brousch](https://github.com/brousch))
- make sure android.branch works with fresh clone [\#44](https://github.com/kivy/buildozer/pull/44) ([akshayaurora](https://github.com/akshayaurora))
- Fixed a typo in setdefault description [\#40](https://github.com/kivy/buildozer/pull/40) ([nithin-bose](https://github.com/nithin-bose))
- Package paths [\#38](https://github.com/kivy/buildozer/pull/38) ([Ian-Foote](https://github.com/Ian-Foote))
- add applibs in path for service too [\#26](https://github.com/kivy/buildozer/pull/26) ([tshirtman](https://github.com/tshirtman))
- fix distribute install before installing every dependencies, fix a few i... [\#25](https://github.com/kivy/buildozer/pull/25) ([tshirtman](https://github.com/tshirtman))

## [0.7](https://github.com/kivy/buildozer/tree/0.7) (2013-09-11)
[Full Changelog](https://github.com/kivy/buildozer/compare/0.2...0.7)

**Closed issues:**

- Builds fail on Ubuntu 13.04 with zlib.h missing [\#18](https://github.com/kivy/buildozer/issues/18)
- "buildozer android update" fails with an error about android.branch [\#12](https://github.com/kivy/buildozer/issues/12)
- Problem Ubuntu compilation on network drive [\#10](https://github.com/kivy/buildozer/issues/10)
- \[app\] "android.permission" contain an unknown permission  [\#6](https://github.com/kivy/buildozer/issues/6)
- buildozer on ios fails at: Command failed: tools/build-all.sh [\#5](https://github.com/kivy/buildozer/issues/5)
- Automatically installing Android SDK fails in file\_rename called from \_install\_android\_sdk [\#4](https://github.com/kivy/buildozer/issues/4)
- buildozer does not support ~ in android.sdk\_path [\#3](https://github.com/kivy/buildozer/issues/3)

**Merged pull requests:**

- Fix typo 'versionning' -\> 'versioning'. [\#29](https://github.com/kivy/buildozer/pull/29) ([Ian-Foote](https://github.com/Ian-Foote))
- Fixed hard-coded Android API 14 [\#23](https://github.com/kivy/buildozer/pull/23) ([brousch](https://github.com/brousch))
- Fixed \#18: Builds fail on Ubuntu 13.04 with zlib.h missing. [\#20](https://github.com/kivy/buildozer/pull/20) ([roskakori](https://github.com/roskakori))
- Europython sprint updates [\#19](https://github.com/kivy/buildozer/pull/19) ([fabiankreutz](https://github.com/fabiankreutz))
- copy the generated apk back from remote [\#16](https://github.com/kivy/buildozer/pull/16) ([akshayaurora](https://github.com/akshayaurora))
- android.add\_jars config option [\#15](https://github.com/kivy/buildozer/pull/15) ([bob-the-hamster](https://github.com/bob-the-hamster))
- Ouya support [\#14](https://github.com/kivy/buildozer/pull/14) ([bob-the-hamster](https://github.com/bob-the-hamster))

## [0.2](https://github.com/kivy/buildozer/tree/0.2) (2012-12-20)


\* *This Change Log was automatically generated by [github_changelog_generator](https://github.com/skywinder/Github-Changelog-Generator)*
